Class: Stytch::CryptoWallets
- Inherits:
-
Object
- Object
- Stytch::CryptoWallets
- Includes:
- RequestHelper
- Defined in:
- lib/stytch/crypto_wallets.rb
Instance Method Summary collapse
-
#authenticate(crypto_wallet_type:, crypto_wallet_address:, signature:, session_token: nil, session_duration_minutes: nil, session_jwt: nil, session_custom_claims: nil, telemetry_id: nil) ⇒ Object
Complete the authentication of a crypto wallet by passing the signature.
-
#authenticate_start(crypto_wallet_type:, crypto_wallet_address:, user_id: nil, session_token: nil, session_jwt: nil, siwe_params: nil) ⇒ Object
Initiate the authentication of a crypto wallet.
-
#initialize(connection) ⇒ CryptoWallets
constructor
A new instance of CryptoWallets.
Methods included from RequestHelper
#delete_request, #get_request, #post_request, #put_request, #request_with_query_params
Constructor Details
#initialize(connection) ⇒ CryptoWallets
Returns a new instance of CryptoWallets.
15 16 17 |
# File 'lib/stytch/crypto_wallets.rb', line 15 def initialize(connection) @connection = connection end |
Instance Method Details
#authenticate(crypto_wallet_type:, crypto_wallet_address:, signature:, session_token: nil, session_duration_minutes: nil, session_jwt: nil, session_custom_claims: nil, telemetry_id: nil) ⇒ Object
Complete the authentication of a crypto wallet by passing the signature.
Parameters:
- crypto_wallet_type
The type of wallet to authenticate. Currently
ethereumandsolanaare supported. Wallets for any EVM-compatible chains (such as Polygon or BSC) are also supported and are grouped under theethereumtype. The type of this field isString.- crypto_wallet_address
The crypto wallet address to authenticate. The type of this field is
String.- signature
The signature from the message challenge. The type of this field is
String.- session_token
The
session_tokenassociated with a User's existing Session. The type of this field is nilableString.- session_duration_minutes
Set the session lifetime to be this many minutes from now. This will start a new session if one doesn't already exist, returning both an opaque
session_tokenandsession_jwtfor this session. Remember that thesession_jwtwill have a fixed lifetime of five minutes regardless of the underlying session duration, and will need to be refreshed over time.
This value must be a minimum of 5 and a maximum of 527040 minutes (366 days).
If a `session_token` or `session_jwt` is provided then a successful authentication will continue to extend the session this many minutes.
If the `session_duration_minutes` parameter is not specified, a Stytch session will not be created.
The type of this field is nilable +Integer+.
- session_jwt
The
session_jwtassociated with a User's existing Session. The type of this field is nilableString.- session_custom_claims
Add a custom claims map to the Session being authenticated. Claims are only created if a Session is initialized by providing a value in
session_duration_minutes. Claims will be included on the Session object and in the JWT. To update a key in an existing Session, supply a new value. To delete a key, supply a null value.
Custom claims made with reserved claims ("iss", "sub", "aud", "exp", "nbf", "iat", "jti") will be ignored. Total custom claims size cannot exceed four kilobytes.
The type of this field is nilable object.
- telemetry_id
If the
telemetry_idis passed, as part of this request, Stytch will call the Fingerprint Lookup API and store the associated fingerprints and IPGEO information for the User. Your workspace must be enabled for Device Fingerprinting to use this feature. The type of this field is nilableString.
Returns:
An object with the following fields:
- request_id
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String.- user_id
The unique ID of the affected User. The type of this field is
String.- session_token
A secret token for a given Stytch Session. The type of this field is
String.- session_jwt
The JSON Web Token (JWT) for a given Stytch Session. The type of this field is
String.- user
The
userobject affected by this API call. See the Get user endpoint for complete response field details. The type of this field isUser(+object+).- status_code
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer.- session
If you initiate a Session, by including
session_duration_minutesin your authenticate call, you'll receive a full Session object in the response.
See Session object for complete response fields.
The type of this field is nilable +Session+ (+object+).
- siwe_params
The parameters of the Sign In With Ethereum (SIWE) message that was signed. The type of this field is nilable
SIWEParamsResponse(+object+).- user_device
If a valid
telemetry_idwas passed in the request and the Fingerprint Lookup API returned results, theuser_deviceresponse field will contain information about the user's device attributes. The type of this field is nilableDeviceInfo(+object+).
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/stytch/crypto_wallets.rb', line 154 def authenticate( crypto_wallet_type:, crypto_wallet_address:, signature:, session_token: nil, session_duration_minutes: nil, session_jwt: nil, session_custom_claims: nil, telemetry_id: nil ) headers = {} request = { crypto_wallet_type: crypto_wallet_type, crypto_wallet_address: crypto_wallet_address, signature: signature } request[:session_token] = session_token unless session_token.nil? request[:session_duration_minutes] = session_duration_minutes unless session_duration_minutes.nil? request[:session_jwt] = session_jwt unless session_jwt.nil? request[:session_custom_claims] = session_custom_claims unless session_custom_claims.nil? request[:telemetry_id] = telemetry_id unless telemetry_id.nil? post_request('/v1/crypto_wallets/authenticate', request, headers) end |
#authenticate_start(crypto_wallet_type:, crypto_wallet_address:, user_id: nil, session_token: nil, session_jwt: nil, siwe_params: nil) ⇒ Object
Initiate the authentication of a crypto wallet. After calling this endpoint, the user will need to sign a message containing the returned challenge field.
For Ethereum crypto wallets, you can optionally use the Sign In With Ethereum (SIWE) protocol for the message by passing in the siwe_params. The only required fields are domain and uri.
If the crypto wallet detects that the domain in the message does not match the website's domain, it will display a warning to the user.
If not using the SIWE protocol, the message will simply consist of the project name and a random string.
Parameters:
- crypto_wallet_type
The type of wallet to authenticate. Currently
ethereumandsolanaare supported. Wallets for any EVM-compatible chains (such as Polygon or BSC) are also supported and are grouped under theethereumtype. The type of this field isString.- crypto_wallet_address
The crypto wallet address to authenticate. The type of this field is
String.- user_id
The unique ID of a specific User. You may use an
external_idhere if one is set for the user. The type of this field is nilableString.- session_token
The
session_tokenassociated with a User's existing Session. The type of this field is nilableString.- session_jwt
The
session_jwtassociated with a User's existing Session. The type of this field is nilableString.- siwe_params
The parameters for a Sign In With Ethereum (SIWE) message. May only be passed if the
crypto_wallet_typeisethereum. The type of this field is nilableSIWEParams(+object+).
Returns:
An object with the following fields:
- request_id
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String.- user_id
The unique ID of the affected User. The type of this field is
String.- challenge
A challenge string to be signed by the wallet in order to prove ownership. The type of this field is
String.- user_created
In
login_or_createendpoints, this field indicates whether or not a User was just created. The type of this field isBoolean.- status_code
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/stytch/crypto_wallets.rb', line 63 def authenticate_start( crypto_wallet_type:, crypto_wallet_address:, user_id: nil, session_token: nil, session_jwt: nil, siwe_params: nil ) headers = {} request = { crypto_wallet_type: crypto_wallet_type, crypto_wallet_address: crypto_wallet_address } request[:user_id] = user_id unless user_id.nil? request[:session_token] = session_token unless session_token.nil? request[:session_jwt] = session_jwt unless session_jwt.nil? request[:siwe_params] = siwe_params unless siwe_params.nil? post_request('/v1/crypto_wallets/authenticate/start', request, headers) end |