Class: Stytch::Passwords::Email
- Inherits:
-
Object
- Object
- Stytch::Passwords::Email
- Includes:
- RequestHelper
- Defined in:
- lib/stytch/passwords.rb
Instance Method Summary collapse
-
#initialize(connection) ⇒ Email
constructor
A new instance of Email.
-
#reset(token:, password:, session_token: nil, session_duration_minutes: nil, session_jwt: nil, code_verifier: nil, session_custom_claims: nil, attributes: nil, options: nil, telemetry_id: nil) ⇒ Object
Reset the user’s password and authenticate them.
-
#reset_start(email:, reset_password_redirect_url: nil, reset_password_expiration_minutes: nil, code_challenge: nil, attributes: nil, login_redirect_url: nil, locale: nil, reset_password_template_id: nil) ⇒ Object
Initiates a password reset for the email address provided.
Methods included from RequestHelper
#delete_request, #get_request, #post_request, #put_request, #request_with_query_params
Constructor Details
#initialize(connection) ⇒ Email
Returns a new instance of Email.
403 404 405 |
# File 'lib/stytch/passwords.rb', line 403 def initialize(connection) @connection = connection end |
Instance Method Details
#reset(token:, password:, session_token: nil, session_duration_minutes: nil, session_jwt: nil, code_verifier: nil, session_custom_claims: nil, attributes: nil, options: nil, telemetry_id: nil) ⇒ Object
Reset the user’s password and authenticate them. This endpoint checks that the magic link ‘token` is valid, hasn’t expired, or already been used – and can optionally require additional security settings, such as the IP address and user agent matching the initial reset request.
The provided password needs to meet our password strength requirements, which can be checked in advance with the password strength endpoint. If the token and password are accepted, the password is securely stored for future authentication and the user is authenticated.
Note that a successful password reset by email will revoke all active sessions for the ‘user_id`.
Parameters:
- token
-
The Passwords ‘token` from the `?token=` query parameter in the URL.
In the redirect URL, the `stytch_token_type` will be `login` or `reset_password`. See examples and read more about redirect URLs [here](https://stytch.com/docs/workspace-management/redirect-urls).The type of this field is
String. - password
-
The password for the user. Any UTF8 character is allowed, e.g. spaces, emojis, non-English characters, etc. The type of this field is
String. - session_token
-
The ‘session_token` associated with a User’s existing Session. The type of this field is nilable
String. - session_duration_minutes
-
Set the session lifetime to be this many minutes from now. This will start a new session if one doesn’t already exist, returning both an opaque ‘session_token` and `session_jwt` for this session. Remember that the `session_jwt` will have a fixed lifetime of five minutes regardless of the underlying session duration, and will need to be refreshed over time.
This value must be a minimum of 5 and a maximum of 527040 minutes (366 days).
If a ‘session_token` or `session_jwt` is provided then a successful authentication will continue to extend the session this many minutes.
If the ‘session_duration_minutes` parameter is not specified, a Stytch session will not be created. The type of this field is nilable
Integer. - session_jwt
-
The ‘session_jwt` associated with a User’s existing Session. The type of this field is nilable
String. - code_verifier
-
A base64url encoded one time secret used to validate that the request starts and ends on the same device. The type of this field is nilable
String. - session_custom_claims
-
Add a custom claims map to the Session being authenticated. Claims are only created if a Session is initialized by providing a value in ‘session_duration_minutes`. Claims will be included on the Session object and in the JWT. To update a key in an existing Session, supply a new value. To delete a key, supply a null value.
Custom claims made with reserved claims (“iss”, “sub”, “aud”, “exp”, “nbf”, “iat”, “jti”) will be ignored. Total custom claims size cannot exceed four kilobytes. The type of this field is nilable
object. - attributes
-
Provided attributes to help with fraud detection. These values are pulled and passed into Stytch endpoints by your application. The type of this field is nilable
Attributes(object). - options
-
Specify optional security settings. The type of this field is nilable
Options(object). - telemetry_id
-
If the ‘telemetry_id` is passed, as part of this request, Stytch will call the [Fingerprint Lookup API](stytch.com/docs/fraud/api/fingerprint-lookup) and store the associated fingerprints and IPGEO information for the User. Your workspace must be enabled for Device Fingerprinting to use this feature. The type of this field is nilable
String.
Returns:
An object with the following fields:
- request_id
-
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String. - user_id
-
The unique ID of the affected User. The type of this field is
String. - session_token
-
A secret token for a given Stytch Session. The type of this field is
String. - session_jwt
-
The JSON Web Token (JWT) for a given Stytch Session. The type of this field is
String. - user
-
The ‘user` object affected by this API call. See the [Get user endpoint](stytch.com/docs/api/get-user) for complete response field details. The type of this field is
User(object). - status_code
-
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer. - session
-
If you initiate a Session, by including ‘session_duration_minutes` in your authenticate call, you’ll receive a full Session object in the response.
See [Session object](stytch.com/docs/api/session-object) for complete response fields.
The type of this field is nilable
Session(object). - user_device
-
If a valid ‘telemetry_id` was passed in the request and the [Fingerprint Lookup API](stytch.com/docs/fraud/api/fingerprint-lookup) returned results, the `user_device` response field will contain information about the user’s device attributes. The type of this field is nilable
DeviceInfo(object).
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/stytch/passwords.rb', line 566 def reset( token:, password:, session_token: nil, session_duration_minutes: nil, session_jwt: nil, code_verifier: nil, session_custom_claims: nil, attributes: nil, options: nil, telemetry_id: nil ) headers = {} request = { token: token, password: password } request[:session_token] = session_token unless session_token.nil? request[:session_duration_minutes] = session_duration_minutes unless session_duration_minutes.nil? request[:session_jwt] = session_jwt unless session_jwt.nil? request[:code_verifier] = code_verifier unless code_verifier.nil? request[:session_custom_claims] = session_custom_claims unless session_custom_claims.nil? request[:attributes] = attributes unless attributes.nil? request[:options] = unless .nil? request[:telemetry_id] = telemetry_id unless telemetry_id.nil? post_request('/v1/passwords/email/reset', request, headers) end |
#reset_start(email:, reset_password_redirect_url: nil, reset_password_expiration_minutes: nil, code_challenge: nil, attributes: nil, login_redirect_url: nil, locale: nil, reset_password_template_id: nil) ⇒ Object
Initiates a password reset for the email address provided. This will trigger an email to be sent to the address, containing a magic link that will allow them to set a new password and authenticate.
Parameters:
-
The email of the User that requested the password reset. The type of this field is
String. - reset_password_redirect_url
-
The URL that the User is redirected to from the reset password magic link. This URL should display your application’s reset password page. Before rendering the reset page, extract the ‘token` from the query parameters. On the reset page, collect the new password and complete the flow by calling the corresponding Password Reset by Email endpoint. If this parameter is not specified, the default Reset Password redirect URL configured in the Dashboard will be used. If you have not set a default Reset Password redirect URL, an error is returned. The type of this field is nilable
String. - reset_password_expiration_minutes
-
Set the expiration for the password reset, in minutes. By default, it expires in 30 minutes. The minimum expiration is 5 minutes and the maximum is 7 days (10080 mins). The type of this field is nilable
Integer. - code_challenge
-
A base64url encoded SHA256 hash of a one time secret used to validate that the request starts and ends on the same device. The type of this field is nilable
String. - attributes
-
Provided attributes to help with fraud detection. These values are pulled and passed into Stytch endpoints by your application. The type of this field is nilable
Attributes(object). - login_redirect_url
-
The URL that Users are redirected to upon clicking the “Log in without password” button in password reset emails.
After Users are redirected to the login redirect URL, your application should retrieve the `token` value from the URL parameters and call the [Magic Link Authenticate endpoint](https://stytch.com/docs/api/authenticate-magic-link) to log the User in without requiring a password reset. If this value is not provided, your project's default login redirect URL will be used. If you have not set a default login redirect URL, an error will be returned.The type of this field is nilable
String. - locale
-
Used to determine which language to use when sending the user this delivery method. Parameter is an [IETF BCP 47 language tag](www.w3.org/International/articles/language-tags/), e.g. ‘“en”`.
Currently supported languages are English (‘“en”`), Spanish (`“es”`), French (`“fr”`) and Brazilian Portuguese (`“pt-br”`); if no value is provided, the copy defaults to English.
Request support for additional languages [here](docs.google.com/forms/d/e/1FAIpQLScZSpAu_m2AmLXRT3F3kap-s_mcV6UTBitYn6CdyWP0-o7YjQ/viewform?usp=sf_link“)!
The type of this field is nilable +ResetStartRequestLocale+ (string enum).
- reset_password_template_id
-
Use a custom template for password reset emails. By default, it will use your default email template. Templates can be added in the [Stytch dashboard](stytch.com/dashboard/templates) using our built-in customization options or custom HTML templates with type “Passwords - Password reset”. The type of this field is nilable
String.
Returns:
An object with the following fields:
- request_id
-
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String. - user_id
-
The unique ID of the affected User. The type of this field is
String. - email_id
-
The unique ID of a specific email address. The type of this field is
String. - status_code
-
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer.
460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 |
# File 'lib/stytch/passwords.rb', line 460 def reset_start( email:, reset_password_redirect_url: nil, reset_password_expiration_minutes: nil, code_challenge: nil, attributes: nil, login_redirect_url: nil, locale: nil, reset_password_template_id: nil ) headers = {} request = { email: email } request[:reset_password_redirect_url] = reset_password_redirect_url unless reset_password_redirect_url.nil? request[:reset_password_expiration_minutes] = reset_password_expiration_minutes unless reset_password_expiration_minutes.nil? request[:code_challenge] = code_challenge unless code_challenge.nil? request[:attributes] = attributes unless attributes.nil? request[:login_redirect_url] = login_redirect_url unless login_redirect_url.nil? request[:locale] = locale unless locale.nil? request[:reset_password_template_id] = reset_password_template_id unless reset_password_template_id.nil? post_request('/v1/passwords/email/reset/start', request, headers) end |