Class: Stytch::Passwords::ExistingPassword
- Inherits:
-
Object
- Object
- Stytch::Passwords::ExistingPassword
- Includes:
- RequestHelper
- Defined in:
- lib/stytch/passwords.rb
Instance Method Summary collapse
-
#initialize(connection) ⇒ ExistingPassword
constructor
A new instance of ExistingPassword.
-
#reset(email:, existing_password:, new_password:, session_token: nil, session_duration_minutes: nil, session_jwt: nil, session_custom_claims: nil, telemetry_id: nil) ⇒ Object
Reset the User's password using their existing password.
Methods included from RequestHelper
#delete_request, #get_request, #post_request, #put_request, #request_with_query_params
Constructor Details
#initialize(connection) ⇒ ExistingPassword
Returns a new instance of ExistingPassword.
599 600 601 |
# File 'lib/stytch/passwords.rb', line 599 def initialize(connection) @connection = connection end |
Instance Method Details
#reset(email:, existing_password:, new_password:, session_token: nil, session_duration_minutes: nil, session_jwt: nil, session_custom_claims: nil, telemetry_id: nil) ⇒ Object
Reset the User's password using their existing password.
Note that a successful password reset via an existing password will revoke all active sessions for the user_id.
Parameters:
The email address of the end user. The type of this field is
String.- existing_password
The user's existing password. The type of this field is
String.- new_password
The new password for the user. The type of this field is
String.- session_token
The
session_tokenassociated with a User's existing Session. The type of this field is nilableString.- session_duration_minutes
Set the session lifetime to be this many minutes from now. This will start a new session if one doesn't already exist, returning both an opaque
session_tokenandsession_jwtfor this session. Remember that thesession_jwtwill have a fixed lifetime of five minutes regardless of the underlying session duration, and will need to be refreshed over time.
This value must be a minimum of 5 and a maximum of 527040 minutes (366 days).
If a `session_token` or `session_jwt` is provided then a successful authentication will continue to extend the session this many minutes.
If the `session_duration_minutes` parameter is not specified, a Stytch session will not be created.
The type of this field is nilable +Integer+.
- session_jwt
The
session_jwtassociated with a User's existing Session. The type of this field is nilableString.- session_custom_claims
Add a custom claims map to the Session being authenticated. Claims are only created if a Session is initialized by providing a value in
session_duration_minutes. Claims will be included on the Session object and in the JWT. To update a key in an existing Session, supply a new value. To delete a key, supply a null value.
Custom claims made with reserved claims ("iss", "sub", "aud", "exp", "nbf", "iat", "jti") will be ignored. Total custom claims size cannot exceed four kilobytes.
The type of this field is nilable object.
- telemetry_id
If the
telemetry_idis passed, as part of this request, Stytch will call the Fingerprint Lookup API and store the associated fingerprints and IPGEO information for the User. Your workspace must be enabled for Device Fingerprinting to use this feature. The type of this field is nilableString.
Returns:
An object with the following fields:
- request_id
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String.- user_id
The unique ID of the affected User. The type of this field is
String.- session_token
A secret token for a given Stytch Session. The type of this field is
String.- session_jwt
The JSON Web Token (JWT) for a given Stytch Session. The type of this field is
String.- user
The
userobject affected by this API call. See the Get user endpoint for complete response field details. The type of this field isUser(+object+).- status_code
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer.- session
If you initiate a Session, by including
session_duration_minutesin your authenticate call, you'll receive a full Session object in the response.
See Session object for complete response fields.
The type of this field is nilable +Session+ (+object+).
- user_device
If a valid
telemetry_idwas passed in the request and the Fingerprint Lookup API returned results, theuser_deviceresponse field will contain information about the user's device attributes. The type of this field is nilableDeviceInfo(+object+).
672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 |
# File 'lib/stytch/passwords.rb', line 672 def reset( email:, existing_password:, new_password:, session_token: nil, session_duration_minutes: nil, session_jwt: nil, session_custom_claims: nil, telemetry_id: nil ) headers = {} request = { email: email, existing_password: existing_password, new_password: new_password } request[:session_token] = session_token unless session_token.nil? request[:session_duration_minutes] = session_duration_minutes unless session_duration_minutes.nil? request[:session_jwt] = session_jwt unless session_jwt.nil? request[:session_custom_claims] = session_custom_claims unless session_custom_claims.nil? request[:telemetry_id] = telemetry_id unless telemetry_id.nil? post_request('/v1/passwords/existing_password/reset', request, headers) end |