Class: Stytch::Passwords::Sessions
- Inherits:
-
Object
- Object
- Stytch::Passwords::Sessions
- Includes:
- RequestHelper
- Defined in:
- lib/stytch/passwords.rb
Instance Method Summary collapse
-
#initialize(connection) ⇒ Sessions
constructor
A new instance of Sessions.
-
#reset(password:, session_token: nil, session_jwt: nil, session_duration_minutes: nil, session_custom_claims: nil, telemetry_id: nil) ⇒ Object
Reset the user’s password using their existing session.
Methods included from RequestHelper
#delete_request, #get_request, #post_request, #put_request, #request_with_query_params
Constructor Details
#initialize(connection) ⇒ Sessions
Returns a new instance of Sessions.
701 702 703 |
# File 'lib/stytch/passwords.rb', line 701 def initialize(connection) @connection = connection end |
Instance Method Details
#reset(password:, session_token: nil, session_jwt: nil, session_duration_minutes: nil, session_custom_claims: nil, telemetry_id: nil) ⇒ Object
Reset the user’s password using their existing session. The endpoint will error if the session does not have a password, email magic link, or email OTP authentication factor that has been issued within the last 5 minutes. This endpoint requires either a session_jwt or session_token be included in the request.
Note that a successful password reset via an existing session will revoke all active sessions for the user_id, except for the one used during the reset flow.
Parameters:
- password
The password for the user. Any UTF8 character is allowed, e.g. spaces, emojis, non-English characters, etc. The type of this field is
String.- session_token
The
session_tokenassociated with a User's existing Session. The type of this field is nilableString.- session_jwt
The
session_jwtassociated with a User's existing Session. The type of this field is nilableString.- session_duration_minutes
Set the session lifetime to be this many minutes from now. This will start a new session if one doesn't already exist, returning both an opaque
session_tokenandsession_jwtfor this session. Remember that thesession_jwtwill have a fixed lifetime of five minutes regardless of the underlying session duration, and will need to be refreshed over time.
This value must be a minimum of 5 and a maximum of 527040 minutes (366 days).
If a `session_token` or `session_jwt` is provided then a successful authentication will continue to extend the session this many minutes.
If the `session_duration_minutes` parameter is not specified, a Stytch session will not be created.
The type of this field is nilable +Integer+.
- session_custom_claims
Add a custom claims map to the Session being authenticated. Claims are only created if a Session is initialized by providing a value in
session_duration_minutes. Claims will be included on the Session object and in the JWT. To update a key in an existing Session, supply a new value. To delete a key, supply a null value.
Custom claims made with reserved claims ("iss", "sub", "aud", "exp", "nbf", "iat", "jti") will be ignored. Total custom claims size cannot exceed four kilobytes.
The type of this field is nilable object.
- telemetry_id
If the
telemetry_idis passed, as part of this request, Stytch will call the Fingerprint Lookup API and store the associated fingerprints and IPGEO information for the User. Your workspace must be enabled for Device Fingerprinting to use this feature. The type of this field is nilableString.
Returns:
An object with the following fields:
- request_id
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String.- user_id
The unique ID of the affected User. The type of this field is
String.- user
The
userobject affected by this API call. See the Get user endpoint for complete response field details. The type of this field isUser(+object+).- session_token
A secret token for a given Stytch Session. The type of this field is
String.- session_jwt
The JSON Web Token (JWT) for a given Stytch Session. The type of this field is
String.- status_code
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer.- session
If you initiate a Session, by including
session_duration_minutesin your authenticate call, you'll receive a full Session object in the response.
See Session object for complete response fields.
The type of this field is nilable +Session+ (+object+).
- user_device
If a valid
telemetry_idwas passed in the request and the Fingerprint Lookup API returned results, theuser_deviceresponse field will contain information about the user's device attributes. The type of this field is nilableDeviceInfo(+object+).
768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'lib/stytch/passwords.rb', line 768 def reset( password:, session_token: nil, session_jwt: nil, session_duration_minutes: nil, session_custom_claims: nil, telemetry_id: nil ) headers = {} request = { password: password } request[:session_token] = session_token unless session_token.nil? request[:session_jwt] = session_jwt unless session_jwt.nil? request[:session_duration_minutes] = session_duration_minutes unless session_duration_minutes.nil? request[:session_custom_claims] = session_custom_claims unless session_custom_claims.nil? request[:telemetry_id] = telemetry_id unless telemetry_id.nil? post_request('/v1/passwords/session/reset', request, headers) end |