Class: Stytch::TOTPs
- Inherits:
-
Object
- Object
- Stytch::TOTPs
- Includes:
- RequestHelper
- Defined in:
- lib/stytch/totps.rb
Instance Method Summary collapse
-
#authenticate(user_id:, totp_code:, session_token: nil, session_duration_minutes: nil, session_jwt: nil, session_custom_claims: nil, telemetry_id: nil) ⇒ Object
Authenticate a TOTP code entered by a user.
-
#create(user_id:, expiration_minutes: nil) ⇒ Object
Create a new TOTP instance for a user.
-
#initialize(connection) ⇒ TOTPs
constructor
A new instance of TOTPs.
-
#recover(user_id:, recovery_code:, session_token: nil, session_duration_minutes: nil, session_jwt: nil, session_custom_claims: nil, telemetry_id: nil) ⇒ Object
Authenticate a recovery code for a TOTP instance.
-
#recovery_codes(user_id:) ⇒ Object
Retrieve the recovery codes for a TOTP instance tied to a User.
Methods included from RequestHelper
#delete_request, #get_request, #post_request, #put_request, #request_with_query_params
Constructor Details
#initialize(connection) ⇒ TOTPs
Returns a new instance of TOTPs.
15 16 17 |
# File 'lib/stytch/totps.rb', line 15 def initialize(connection) @connection = connection end |
Instance Method Details
#authenticate(user_id:, totp_code:, session_token: nil, session_duration_minutes: nil, session_jwt: nil, session_custom_claims: nil, telemetry_id: nil) ⇒ Object
Authenticate a TOTP code entered by a user.
Parameters:
- user_id
The
user_idof an active user the TOTP registration should be tied to. You may use anexternal_idhere if one is set for the user. The type of this field isString.- totp_code
The TOTP code to authenticate. The TOTP code should consist of 6 digits. The type of this field is
String.- session_token
The
session_tokenassociated with a User's existing Session. The type of this field is nilableString.- session_duration_minutes
Set the session lifetime to be this many minutes from now. This will start a new session if one doesn't already exist, returning both an opaque
session_tokenandsession_jwtfor this session. Remember that thesession_jwtwill have a fixed lifetime of five minutes regardless of the underlying session duration, and will need to be refreshed over time.
This value must be a minimum of 5 and a maximum of 527040 minutes (366 days).
If a `session_token` or `session_jwt` is provided then a successful authentication will continue to extend the session this many minutes.
If the `session_duration_minutes` parameter is not specified, a Stytch session will not be created.
The type of this field is nilable +Integer+.
- session_jwt
The
session_jwtassociated with a User's existing Session. The type of this field is nilableString.- session_custom_claims
Add a custom claims map to the Session being authenticated. Claims are only created if a Session is initialized by providing a value in
session_duration_minutes. Claims will be included on the Session object and in the JWT. To update a key in an existing Session, supply a new value. To delete a key, supply a null value.
Custom claims made with reserved claims ("iss", "sub", "aud", "exp", "nbf", "iat", "jti") will be ignored. Total custom claims size cannot exceed four kilobytes.
The type of this field is nilable object.
- telemetry_id
If the
telemetry_idis passed, as part of this request, Stytch will call the Fingerprint Lookup API and store the associated fingerprints and IPGEO information for the User. Your workspace must be enabled for Device Fingerprinting to use this feature. The type of this field is nilableString.
Returns:
An object with the following fields:
- request_id
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String.- user_id
The unique ID of the affected User. The type of this field is
String.- session_token
A secret token for a given Stytch Session. The type of this field is
String.- totp_id
The unique ID for a TOTP instance. The type of this field is
String.- session_jwt
The JSON Web Token (JWT) for a given Stytch Session. The type of this field is
String.- user
The
userobject affected by this API call. See the Get user endpoint for complete response field details. The type of this field isUser(+object+).- status_code
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer.- session
If you initiate a Session, by including
session_duration_minutesin your authenticate call, you'll receive a full Session object in the response.
See Session object for complete response fields.
The type of this field is nilable +Session+ (+object+).
- user_device
If a valid
telemetry_idwas passed in the request and the Fingerprint Lookup API returned results, theuser_deviceresponse field will contain information about the user's device attributes. The type of this field is nilableDeviceInfo(+object+).
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/stytch/totps.rb', line 135 def authenticate( user_id:, totp_code:, session_token: nil, session_duration_minutes: nil, session_jwt: nil, session_custom_claims: nil, telemetry_id: nil ) headers = {} request = { user_id: user_id, totp_code: totp_code } request[:session_token] = session_token unless session_token.nil? request[:session_duration_minutes] = session_duration_minutes unless session_duration_minutes.nil? request[:session_jwt] = session_jwt unless session_jwt.nil? request[:session_custom_claims] = session_custom_claims unless session_custom_claims.nil? request[:telemetry_id] = telemetry_id unless telemetry_id.nil? post_request('/v1/totps/authenticate', request, headers) end |
#create(user_id:, expiration_minutes: nil) ⇒ Object
Create a new TOTP instance for a user. The user can use the authenticator application of their choice to scan the QR code or enter the secret.
Parameters:
- user_id
The
user_idof an active user the TOTP registration should be tied to. You may use anexternal_idhere if one is set for the user. The type of this field isString.- expiration_minutes
The expiration for the TOTP instance. If the newly created TOTP is not authenticated within this time frame the TOTP will be unusable. Defaults to 1440 (1 day) with a minimum of 5 and a maximum of 1440. The type of this field is nilable
Integer.
Returns:
An object with the following fields:
- request_id
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String.- totp_id
The unique ID for a TOTP instance. The type of this field is
String.- secret
The TOTP secret key shared between the authenticator app and the server used to generate TOTP codes. The type of this field is
String.- qr_code
The QR code image encoded in base64. The type of this field is
String.- recovery_codes
The recovery codes used to authenticate the user without an authenticator app. The type of this field is list of
String.- user
The
userobject affected by this API call. See the Get user endpoint for complete response field details. The type of this field isUser(+object+).- user_id
The unique ID of the affected User. The type of this field is
String.- status_code
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer.
55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/stytch/totps.rb', line 55 def create( user_id:, expiration_minutes: nil ) headers = {} request = { user_id: user_id } request[:expiration_minutes] = expiration_minutes unless expiration_minutes.nil? post_request('/v1/totps', request, headers) end |
#recover(user_id:, recovery_code:, session_token: nil, session_duration_minutes: nil, session_jwt: nil, session_custom_claims: nil, telemetry_id: nil) ⇒ Object
Authenticate a recovery code for a TOTP instance.
Parameters:
- user_id
The
user_idof an active user the TOTP registration should be tied to. You may use anexternal_idhere if one is set for the user. The type of this field isString.- recovery_code
The recovery code to authenticate. The type of this field is
String.- session_token
The
session_tokenassociated with a User's existing Session. The type of this field is nilableString.- session_duration_minutes
Set the session lifetime to be this many minutes from now. This will start a new session if one doesn't already exist, returning both an opaque
session_tokenandsession_jwtfor this session. Remember that thesession_jwtwill have a fixed lifetime of five minutes regardless of the underlying session duration, and will need to be refreshed over time.
This value must be a minimum of 5 and a maximum of 527040 minutes (366 days).
If a `session_token` or `session_jwt` is provided then a successful authentication will continue to extend the session this many minutes.
If the `session_duration_minutes` parameter is not specified, a Stytch session will not be created.
The type of this field is nilable +Integer+.
- session_jwt
The
session_jwtassociated with a User's existing Session. The type of this field is nilableString.- session_custom_claims
Add a custom claims map to the Session being authenticated. Claims are only created if a Session is initialized by providing a value in
session_duration_minutes. Claims will be included on the Session object and in the JWT. To update a key in an existing Session, supply a new value. To delete a key, supply a null value.
Custom claims made with reserved claims ("iss", "sub", "aud", "exp", "nbf", "iat", "jti") will be ignored. Total custom claims size cannot exceed four kilobytes.
The type of this field is nilable object.
- telemetry_id
If the
telemetry_idis passed, as part of this request, Stytch will call the Fingerprint Lookup API and store the associated fingerprints and IPGEO information for the User. Your workspace must be enabled for Device Fingerprinting to use this feature. The type of this field is nilableString.
Returns:
An object with the following fields:
- request_id
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String.- totp_id
The unique ID for a TOTP instance. The type of this field is
String.- user_id
The unique ID of the affected User. The type of this field is
String.- session_token
A secret token for a given Stytch Session. The type of this field is
String.- session_jwt
The JSON Web Token (JWT) for a given Stytch Session. The type of this field is
String.- user
The
userobject affected by this API call. See the Get user endpoint for complete response field details. The type of this field isUser(+object+).- status_code
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer.- session
If you initiate a Session, by including
session_duration_minutesin your authenticate call, you'll receive a full Session object in the response.
See Session object for complete response fields.
The type of this field is nilable +Session+ (+object+).
- user_device
If a valid
telemetry_idwas passed in the request and the Fingerprint Lookup API returned results, theuser_deviceresponse field will contain information about the user's device attributes. The type of this field is nilableDeviceInfo(+object+).
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/stytch/totps.rb', line 257 def recover( user_id:, recovery_code:, session_token: nil, session_duration_minutes: nil, session_jwt: nil, session_custom_claims: nil, telemetry_id: nil ) headers = {} request = { user_id: user_id, recovery_code: recovery_code } request[:session_token] = session_token unless session_token.nil? request[:session_duration_minutes] = session_duration_minutes unless session_duration_minutes.nil? request[:session_jwt] = session_jwt unless session_jwt.nil? request[:session_custom_claims] = session_custom_claims unless session_custom_claims.nil? request[:telemetry_id] = telemetry_id unless telemetry_id.nil? post_request('/v1/totps/recover', request, headers) end |
#recovery_codes(user_id:) ⇒ Object
Retrieve the recovery codes for a TOTP instance tied to a User.
Parameters:
- user_id
The
user_idof an active user the TOTP registration should be tied to. You may use anexternal_idhere if one is set for the user. The type of this field isString.
Returns:
An object with the following fields:
- request_id
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String.- user_id
The unique ID of the affected User. The type of this field is
String.- totps
An array containing a list of all TOTP instances (along with their recovery codes) for a given User in the Stytch API. The type of this field is list of
TOTP(+object+).- status_code
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer.
179 180 181 182 183 184 185 186 187 188 |
# File 'lib/stytch/totps.rb', line 179 def recovery_codes( user_id: ) headers = {} request = { user_id: user_id } post_request('/v1/totps/recovery_codes', request, headers) end |