Class: StytchB2B::MagicLinks

Inherits:
Object
  • Object
show all
Includes:
Stytch::RequestHelper
Defined in:
lib/stytch/b2b_magic_links.rb

Defined Under Namespace

Classes: Discovery, Email

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Stytch::RequestHelper

#delete_request, #get_request, #post_request, #put_request, #request_with_query_params

Constructor Details

#initialize(connection) ⇒ MagicLinks

Returns a new instance of MagicLinks.



16
17
18
19
20
21
# File 'lib/stytch/b2b_magic_links.rb', line 16

def initialize(connection)
  @connection = connection

  @email = StytchB2B::MagicLinks::Email.new(@connection)
  @discovery = StytchB2B::MagicLinks::Discovery.new(@connection)
end

Instance Attribute Details

#discoveryObject (readonly)

Returns the value of attribute discovery.



14
15
16
# File 'lib/stytch/b2b_magic_links.rb', line 14

def discovery
  @discovery
end

#emailObject (readonly)

Returns the value of attribute email.



14
15
16
# File 'lib/stytch/b2b_magic_links.rb', line 14

def email
  @email
end

Instance Method Details

#authenticate(magic_links_token:, pkce_code_verifier: nil, session_token: nil, session_jwt: nil, session_duration_minutes: nil, session_custom_claims: nil, locale: nil, intermediate_session_token: nil, telemetry_id: nil) ⇒ Object

Authenticate a Member with a Magic Link. This endpoint requires a Magic Link token that is not expired or previously used. If the Member's status is pending or invited, they will be updated to active. Provide the session_duration_minutes parameter to set the lifetime of the session. If the session_duration_minutes parameter is not specified, a Stytch session will be created with a 60 minute duration.

If the Member is required to complete MFA to log in to the Organization, the returned value of member_authenticated will be false, and an intermediate_session_token will be returned. The intermediate_session_token can be passed into the OTP SMS Authenticate endpoint, TOTP Authenticate endpoint, or Recovery Codes Recover endpoint to complete the MFA step and acquire a full member session. The intermediate_session_token can also be used with the Exchange Intermediate Session endpoint or the Create Organization via Discovery endpoint to join a different Organization or create a new one. The session_duration_minutes and session_custom_claims parameters will be ignored.

If a valid session_token or session_jwt is passed in, the Member will not be required to complete an MFA step.

Parameters:

magic_links_token

The Email Magic Link token to authenticate. The type of this field is String.

pkce_code_verifier

A base64url encoded one time secret used to validate that the request starts and ends on the same device. The type of this field is nilable String.

session_token

Reuse an existing session instead of creating a new one. If you provide a session_token, Stytch will update the session. If the session_token and magic_links_token belong to different Members, the session_token will be ignored. This endpoint will error if both session_token and session_jwt are provided. The type of this field is nilable String.

session_jwt

Reuse an existing session instead of creating a new one. If you provide a session_jwt, Stytch will update the session. If the session_jwt and magic_links_token belong to different Members, the session_jwt will be ignored. This endpoint will error if both session_token and session_jwt are provided. The type of this field is nilable String.

session_duration_minutes

Set the session lifetime to be this many minutes from now. This will start a new session if one doesn't already exist, returning both an opaque session_token and session_jwt for this session. Remember that the session_jwt will have a fixed lifetime of five minutes regardless of the underlying session duration, and will need to be refreshed over time.

This value must be a minimum of 5 and a maximum of 527040 minutes (366 days).

If a `session_token` or `session_jwt` is provided then a successful authentication will continue to extend the session this many minutes.

If the `session_duration_minutes` parameter is not specified, a Stytch session will be created with a 60 minute duration. If you don't want
to use the Stytch session product, you can ignore the session fields in the response.
The type of this field is nilable +Integer+.
session_custom_claims

Add a custom claims map to the Session being authenticated. Claims are only created if a Session is initialized by providing a value in session_duration_minutes. Claims will be included on the Session object and in the JWT. To update a key in an existing Session, supply a new value. To delete a key, supply a null value. Custom claims made with reserved claims (iss, sub, aud, exp, nbf, iat, jti) will be ignored. Total custom claims size cannot exceed four kilobytes. The type of this field is nilable object.

locale

If the Member needs to complete an MFA step, and the Member has a phone number, this endpoint will pre-emptively send a one-time passcode (OTP) to the Member's phone number. The locale argument will be used to determine which language to use when sending the passcode.

Parameter is an IETF BCP 47 language tag, e.g. "en".

Currently supported languages are English ("en"), Spanish ("es"), and Brazilian Portuguese ("pt-br"); if no value is provided, the copy defaults to English.

Request support for additional languages here!

The type of this field is nilable +AuthenticateRequestLocale+ (string enum).
intermediate_session_token

Adds this primary authentication factor to the intermediate session token. If the resulting set of factors satisfies the organization's primary authentication requirements and MFA requirements, the intermediate session token will be consumed and converted to a member session. If not, the same intermediate session token will be returned. The type of this field is nilable String.

telemetry_id

If the telemetry_id is passed, as part of this request, Stytch will call the Fingerprint Lookup API and store the associated fingerprints and IPGEO information for the Member. Your workspace must be enabled for Device Fingerprinting to use this feature. The type of this field is nilable String.

Returns:

An object with the following fields:

request_id

Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is String.

member_id

Globally unique UUID that identifies a specific Member. The type of this field is String.

method_id

The email or device involved in the authentication. The type of this field is String.

reset_sessions

This field is deprecated. The type of this field is Boolean.

organization_id

Globally unique UUID that identifies a specific Organization. The organization_id is critical to perform operations on an Organization, so be sure to preserve this value. The type of this field is String.

member

The Member object The type of this field is Member (+object+).

session_token

A secret token for a given Stytch Session. The type of this field is String.

session_jwt

The JSON Web Token (JWT) for a given Stytch Session. The type of this field is String.

organization

The Organization object. The type of this field is Organization (+object+).

intermediate_session_token

The returned Intermediate Session Token contains an Email Magic Link factor associated with the Member's email address. If this value is non-empty, the member must complete an MFA step to finish logging in to the Organization. The token can be used with the OTP SMS Authenticate endpoint, TOTP Authenticate endpoint, or Recovery Codes Recover endpoint to complete an MFA flow and log in to the Organization. The token has a default expiry of 10 minutes. It can also be used with the Exchange Intermediate Session endpoint to join a specific Organization that allows the factors represented by the intermediate session token; or the Create Organization via Discovery endpoint to create a new Organization and Member. Intermediate Session Tokens have a default expiry of 10 minutes. The type of this field is String.

member_authenticated

Indicates whether the Member is fully authenticated. If false, the Member needs to complete an MFA step to log in to the Organization. The type of this field is Boolean.

status_code

The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is Integer.

member_session

The Session object. The type of this field is nilable MemberSession (+object+).

mfa_required

Information about the MFA requirements of the Organization and the Member's options for fulfilling MFA. The type of this field is nilable MfaRequired (+object+).

primary_required

(no documentation yet) The type of this field is nilable PrimaryRequired (+object+).

member_device

If a valid telemetry_id was passed in the request and the Fingerprint Lookup API returned results, the member_device response field will contain information about the member's device attributes. The type of this field is nilable DeviceInfo (+object+).

intermediate_session_token_expires_at

(no documentation yet) The type of this field is nilable String.



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/stytch/b2b_magic_links.rb', line 139

def authenticate(
  magic_links_token:,
  pkce_code_verifier: nil,
  session_token: nil,
  session_jwt: nil,
  session_duration_minutes: nil,
  session_custom_claims: nil,
  locale: nil,
  intermediate_session_token: nil,
  telemetry_id: nil
)
  headers = {}
  request = {
    magic_links_token: magic_links_token
  }
  request[:pkce_code_verifier] = pkce_code_verifier unless pkce_code_verifier.nil?
  request[:session_token] = session_token unless session_token.nil?
  request[:session_jwt] = session_jwt unless session_jwt.nil?
  request[:session_duration_minutes] = session_duration_minutes unless session_duration_minutes.nil?
  request[:session_custom_claims] = session_custom_claims unless session_custom_claims.nil?
  request[:locale] = locale unless locale.nil?
  request[:intermediate_session_token] = intermediate_session_token unless intermediate_session_token.nil?
  request[:telemetry_id] = telemetry_id unless telemetry_id.nil?

  post_request('/v1/b2b/magic_links/authenticate', request, headers)
end