Class: StytchB2B::MagicLinks::Email::InviteRequestOptions

Inherits:
Object
  • Object
show all
Defined in:
lib/stytch/b2b_magic_links.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(authorization: nil) ⇒ InviteRequestOptions

Returns a new instance of InviteRequestOptions.



173
174
175
176
177
# File 'lib/stytch/b2b_magic_links.rb', line 173

def initialize(
  authorization: nil
)
  @authorization = authorization
end

Instance Attribute Details

#authorizationObject

Optional authorization object. Pass in an active Stytch Member session token or session JWT and the request will be run using that member’s permissions.



171
172
173
# File 'lib/stytch/b2b_magic_links.rb', line 171

def authorization
  @authorization
end

Instance Method Details

#to_headersObject



179
180
181
182
183
# File 'lib/stytch/b2b_magic_links.rb', line 179

def to_headers
  headers = {}
  headers.merge!(@authorization.to_headers) if authorization
  headers
end