Class: StytchB2B::OTPs::Email
- Inherits:
-
Object
- Object
- StytchB2B::OTPs::Email
- Includes:
- Stytch::RequestHelper
- Defined in:
- lib/stytch/b2b_otp.rb
Defined Under Namespace
Classes: Discovery
Instance Attribute Summary collapse
-
#discovery ⇒ Object
readonly
Returns the value of attribute discovery.
Instance Method Summary collapse
-
#authenticate(organization_id:, email_address:, code:, session_token: nil, session_jwt: nil, intermediate_session_token: nil, session_duration_minutes: nil, session_custom_claims: nil, locale: nil, telemetry_id: nil) ⇒ Object
Authenticate a Member with a one-time passcode (OTP).
-
#initialize(connection) ⇒ Email
constructor
A new instance of Email.
-
#login_or_signup(organization_id:, email_address:, login_template_id: nil, signup_template_id: nil, locale: nil, login_expiration_minutes: nil, signup_expiration_minutes: nil) ⇒ Object
Send either a login or signup email OTP to a Member.
Methods included from Stytch::RequestHelper
#delete_request, #get_request, #post_request, #put_request, #request_with_query_params
Constructor Details
#initialize(connection) ⇒ Email
Returns a new instance of Email.
256 257 258 259 260 |
# File 'lib/stytch/b2b_otp.rb', line 256 def initialize(connection) @connection = connection @discovery = StytchB2B::OTPs::Email::Discovery.new(@connection) end |
Instance Attribute Details
#discovery ⇒ Object (readonly)
Returns the value of attribute discovery.
254 255 256 |
# File 'lib/stytch/b2b_otp.rb', line 254 def discovery @discovery end |
Instance Method Details
#authenticate(organization_id:, email_address:, code:, session_token: nil, session_jwt: nil, intermediate_session_token: nil, session_duration_minutes: nil, session_custom_claims: nil, locale: nil, telemetry_id: nil) ⇒ Object
Authenticate a Member with a one-time passcode (OTP). This endpoint requires an OTP that is not expired or previously used.
OTPs have a default expiry of 10 minutes. If the Member's status is pending or invited, they will be updated to active.
Provide the session_duration_minutes parameter to set the lifetime of the session. If the session_duration_minutes parameter is not specified, a Stytch session will be created with a 60 minute duration.
If the Member is required to complete MFA to log in to the Organization, the returned value of member_authenticated will be false, and an intermediate_session_token will be returned.
The intermediate_session_token can be passed into the OTP SMS Authenticate endpoint, TOTP Authenticate endpoint,
or Recovery Codes Recover endpoint to complete the MFA step and acquire a full member session.
The intermediate_session_token can also be used with the Exchange Intermediate Session endpoint or the Create Organization via Discovery endpoint to join a different Organization or create a new one.
The session_duration_minutes and session_custom_claims parameters will be ignored.
If a valid session_token or session_jwt is passed in, the Member will not be required to complete an MFA step.
Parameters:
- organization_id
Globally unique UUID that identifies a specific Organization. The
organization_idis critical to perform operations on an Organization, so be sure to preserve this value. You may also use the organization_slug or organization_external_id here as a convenience. The type of this field isString.- email_address
The email address of the Member. The type of this field is
String.- code
The code to authenticate. The type of this field is
String.- session_token
A secret token for a given Stytch Session. The type of this field is nilable
String.- session_jwt
The JSON Web Token (JWT) for a given Stytch Session. The type of this field is nilable
String.- intermediate_session_token
The Intermediate Session Token. This token does not necessarily belong to a specific instance of a Member, but represents a bag of factors that may be converted to a member session. The token can be used with the OTP SMS Authenticate endpoint, TOTP Authenticate endpoint, or Recovery Codes Recover endpoint to complete an MFA flow and log in to the Organization. The token has a default expiry of 10 minutes. It can also be used with the Exchange Intermediate Session endpoint to join a specific Organization that allows the factors represented by the intermediate session token; or the Create Organization via Discovery endpoint to create a new Organization and Member. Intermediate Session Tokens have a default expiry of 10 minutes. The type of this field is nilable
String.- session_duration_minutes
Set the session lifetime to be this many minutes from now. This will start a new session if one doesn't already exist, returning both an opaque
session_tokenandsession_jwtfor this session. Remember that thesession_jwtwill have a fixed lifetime of five minutes regardless of the underlying session duration, and will need to be refreshed over time.
This value must be a minimum of 5 and a maximum of 527040 minutes (366 days).
If a `session_token` or `session_jwt` is provided then a successful authentication will continue to extend the session this many minutes.
If the `session_duration_minutes` parameter is not specified, a Stytch session will be created with a 60 minute duration. If you don't want
to use the Stytch session product, you can ignore the session fields in the response.
The type of this field is nilable +Integer+.
- session_custom_claims
Add a custom claims map to the Session being authenticated. Claims are only created if a Session is initialized by providing a value in
session_duration_minutes. Claims will be included on the Session object and in the JWT. To update a key in an existing Session, supply a new value. To delete a key, supply a null value. Custom claims made with reserved claims (iss,sub,aud,exp,nbf,iat,jti) will be ignored. Total custom claims size cannot exceed four kilobytes. The type of this field is nilableobject.- locale
Used to determine which language to use when sending the user this delivery method. Parameter is an IETF BCP 47 language tag, e.g.
"en".
Currently supported languages are English ("en"), Spanish ("es"), French ("fr") and Brazilian Portuguese ("pt-br"); if no value is provided, the copy defaults to English.
Request support for additional languages here!
The type of this field is nilable +AuthenticateRequestLocale+ (string enum).
- telemetry_id
If the
telemetry_idis passed, as part of this request, Stytch will call the Fingerprint Lookup API and store the associated fingerprints and IPGEO information for the Member. Your workspace must be enabled for Device Fingerprinting to use this feature. The type of this field is nilableString.
Returns:
An object with the following fields:
- request_id
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String.- member_id
Globally unique UUID that identifies a specific Member. The type of this field is
String.- method_id
The email or device involved in the authentication. The type of this field is
String.- organization_id
Globally unique UUID that identifies a specific Organization. The
organization_idis critical to perform operations on an Organization, so be sure to preserve this value. The type of this field isString.- member
The Member object The type of this field is
Member(+object+).- session_token
A secret token for a given Stytch Session. The type of this field is
String.- session_jwt
The JSON Web Token (JWT) for a given Stytch Session. The type of this field is
String.- organization
The Organization object. The type of this field is
Organization(+object+).- intermediate_session_token
The Intermediate Session Token. This token does not necessarily belong to a specific instance of a Member, but represents a bag of factors that may be converted to a member session. The token can be used with the OTP SMS Authenticate endpoint, TOTP Authenticate endpoint, or Recovery Codes Recover endpoint to complete an MFA flow and log in to the Organization. The token has a default expiry of 10 minutes. It can also be used with the Exchange Intermediate Session endpoint to join a specific Organization that allows the factors represented by the intermediate session token; or the Create Organization via Discovery endpoint to create a new Organization and Member. Intermediate Session Tokens have a default expiry of 10 minutes. The type of this field is
String.- member_authenticated
Indicates whether the Member is fully authenticated. If false, the Member needs to complete an MFA step to log in to the Organization. The type of this field is
Boolean.- status_code
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer.- member_session
The Session object. The type of this field is nilable
MemberSession(+object+).- mfa_required
Information about the MFA requirements of the Organization and the Member's options for fulfilling MFA. The type of this field is nilable
MfaRequired(+object+).- primary_required
(no documentation yet) The type of this field is nilable
PrimaryRequired(+object+).- member_device
If a valid
telemetry_idwas passed in the request and the Fingerprint Lookup API returned results, themember_deviceresponse field will contain information about the member's device attributes. The type of this field is nilableDeviceInfo(+object+).- intermediate_session_token_expires_at
(no documentation yet) The type of this field is nilable
String.
448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 |
# File 'lib/stytch/b2b_otp.rb', line 448 def authenticate( organization_id:, email_address:, code:, session_token: nil, session_jwt: nil, intermediate_session_token: nil, session_duration_minutes: nil, session_custom_claims: nil, locale: nil, telemetry_id: nil ) headers = {} request = { organization_id: organization_id, email_address: email_address, code: code } request[:session_token] = session_token unless session_token.nil? request[:session_jwt] = session_jwt unless session_jwt.nil? request[:intermediate_session_token] = intermediate_session_token unless intermediate_session_token.nil? request[:session_duration_minutes] = session_duration_minutes unless session_duration_minutes.nil? request[:session_custom_claims] = session_custom_claims unless session_custom_claims.nil? request[:locale] = locale unless locale.nil? request[:telemetry_id] = telemetry_id unless telemetry_id.nil? post_request('/v1/b2b/otps/email/authenticate', request, headers) end |
#login_or_signup(organization_id:, email_address:, login_template_id: nil, signup_template_id: nil, locale: nil, login_expiration_minutes: nil, signup_expiration_minutes: nil) ⇒ Object
Send either a login or signup email OTP to a Member. A new, pending, or invited Member will receive a signup email OTP. Non-active members will have a pending status until they successfully authenticate. An active Member will receive a login email OTP.
The OTP is valid for 10 minutes. Only the most recently sent OTP is valid: when an OTP is sent, all OTPs previously sent to the same email address are invalidated, even if unused or unexpired.
Parameters:
- organization_id
Globally unique UUID that identifies a specific Organization. The
organization_idis critical to perform operations on an Organization, so be sure to preserve this value. You may also use the organization_slug or organization_external_id here as a convenience. The type of this field isString.- email_address
The email address of the Member. The type of this field is
String.- login_template_id
Use a custom template for login emails. By default, it will use your default email template. Templates can be added in the Stytch dashboard using our built-in customization options or custom HTML templates with type “OTP - Login”. The type of this field is nilable
String.- signup_template_id
Use a custom template for signup emails. By default, it will use your default email template. Templates can be added in the Stytch dashboard using our built-in customization options or custom HTML templates with type “OTP - Signup”. The type of this field is nilable
String.- locale
Used to determine which language to use when sending the user this delivery method. Parameter is an IETF BCP 47 language tag, e.g.
"en".
Currently supported languages are English ("en"), Spanish ("es"), French ("fr") and Brazilian Portuguese ("pt-br"); if no value is provided, the copy defaults to English.
Request support for additional languages here!
The type of this field is nilable +LoginOrSignupRequestLocale+ (string enum).
- login_expiration_minutes
The expiration time, in minutes, for a login OTP email to a Member. If not authenticated within this time frame, the OTP will need to be resent. Defaults to 10 with a minimum of 2 and a maximum of 15. The type of this field is nilable
Integer.- signup_expiration_minutes
The expiration time, in minutes, for a signup OTP email to a Member. If not authenticated within this time frame, the OTP will need to be resent. Defaults to 10 with a minimum of 2 and a maximum of 15. The type of this field is nilable
Integer.
Returns:
An object with the following fields:
- request_id
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String.- member_id
Globally unique UUID that identifies a specific Member. The type of this field is
String.- member_created
A flag indicating
trueif a new Member object was created andfalseif the Member object already existed. The type of this field isBoolean.- member
The Member object The type of this field is
Member(+object+).- organization
The Organization object. The type of this field is
Organization(+object+).- status_code
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer.
314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/stytch/b2b_otp.rb', line 314 def login_or_signup( organization_id:, email_address:, login_template_id: nil, signup_template_id: nil, locale: nil, login_expiration_minutes: nil, signup_expiration_minutes: nil ) headers = {} request = { organization_id: organization_id, email_address: email_address } request[:login_template_id] = login_template_id unless login_template_id.nil? request[:signup_template_id] = signup_template_id unless signup_template_id.nil? request[:locale] = locale unless locale.nil? request[:login_expiration_minutes] = login_expiration_minutes unless login_expiration_minutes.nil? request[:signup_expiration_minutes] = signup_expiration_minutes unless signup_expiration_minutes.nil? post_request('/v1/b2b/otps/email/login_or_signup', request, headers) end |