Class: StytchB2B::OTPs::Sms
- Inherits:
-
Object
- Object
- StytchB2B::OTPs::Sms
- Includes:
- Stytch::RequestHelper
- Defined in:
- lib/stytch/b2b_otp.rb
Instance Method Summary collapse
-
#authenticate(organization_id:, member_id:, code:, intermediate_session_token: nil, session_token: nil, session_jwt: nil, session_duration_minutes: nil, session_custom_claims: nil, set_mfa_enrollment: nil, set_default_mfa: nil, telemetry_id: nil) ⇒ Object
SMS OTPs may not be used as a primary authentication mechanism.
-
#initialize(connection) ⇒ Sms
constructor
A new instance of Sms.
-
#send(organization_id:, member_id:, mfa_phone_number: nil, locale: nil, intermediate_session_token: nil, session_token: nil, session_jwt: nil) ⇒ Object
Send a One-Time Passcode (OTP) to a Member's phone number.
Methods included from Stytch::RequestHelper
#delete_request, #get_request, #post_request, #put_request, #request_with_query_params
Constructor Details
#initialize(connection) ⇒ Sms
Returns a new instance of Sms.
26 27 28 |
# File 'lib/stytch/b2b_otp.rb', line 26 def initialize(connection) @connection = connection end |
Instance Method Details
#authenticate(organization_id:, member_id:, code:, intermediate_session_token: nil, session_token: nil, session_jwt: nil, session_duration_minutes: nil, session_custom_claims: nil, set_mfa_enrollment: nil, set_default_mfa: nil, telemetry_id: nil) ⇒ Object
SMS OTPs may not be used as a primary authentication mechanism. They can be used to complete an MFA requirement, or they can be used as a step-up factor to be added to an existing session.
This endpoint verifies that the one-time passcode (OTP) is valid and hasn't expired or been previously used. OTP codes expire after two minutes.
A given Member may only have a single active OTP code at any given time. If a Member requests another OTP code before the first one has expired, the first one will be invalidated.
Exactly one of intermediate_session_token, session_token, or session_jwt must be provided in the request.
If an intermediate session token is provided, this operation will consume it.
Intermediate session tokens are generated upon successful calls to primary authenticate methods in the case where MFA is required, such as email magic link authenticate, or upon successful calls to discovery authenticate methods, such as email magic link discovery authenticate.
If the Organization's MFA policy is REQUIRED_FOR_ALL, a successful OTP authentication will change the Member's mfa_enrolled status to true if it is not already true.
If the Organization's MFA policy is OPTIONAL, the Member's MFA enrollment can be toggled by passing in a value for the set_mfa_enrollment field.
The Member's MFA enrollment can also be toggled through the Update Member endpoint.
Provide the session_duration_minutes parameter to set the lifetime of the session. If the session_duration_minutes parameter is not specified, a Stytch session will be created with a duration of 60 minutes.
Parameters:
- organization_id
Globally unique UUID that identifies a specific Organization. The
organization_idis critical to perform operations on an Organization, so be sure to preserve this value. You may also use the organization_slug or organization_external_id here as a convenience. The type of this field isString.- member_id
Globally unique UUID that identifies a specific Member. The
member_idis critical to perform operations on a Member, so be sure to preserve this value. You may use an external_id here if one is set for the member. The type of this field isString.- code
The code to authenticate. The type of this field is
String.- intermediate_session_token
The Intermediate Session Token. This token does not necessarily belong to a specific instance of a Member, but represents a bag of factors that may be converted to a member session. The token can be used with the OTP SMS Authenticate endpoint, TOTP Authenticate endpoint, or Recovery Codes Recover endpoint to complete an MFA flow and log in to the Organization. The token has a default expiry of 10 minutes. It can also be used with the Exchange Intermediate Session endpoint to join a specific Organization that allows the factors represented by the intermediate session token; or the Create Organization via Discovery endpoint to create a new Organization and Member. Intermediate Session Tokens have a default expiry of 10 minutes. The type of this field is nilable
String.- session_token
A secret token for a given Stytch Session. The type of this field is nilable
String.- session_jwt
The JSON Web Token (JWT) for a given Stytch Session. The type of this field is nilable
String.- session_duration_minutes
Set the session lifetime to be this many minutes from now. This will start a new session if one doesn't already exist, returning both an opaque
session_tokenandsession_jwtfor this session. Remember that thesession_jwtwill have a fixed lifetime of five minutes regardless of the underlying session duration, and will need to be refreshed over time.
This value must be a minimum of 5 and a maximum of 527040 minutes (366 days).
If a `session_token` or `session_jwt` is provided then a successful authentication will continue to extend the session this many minutes.
If the `session_duration_minutes` parameter is not specified, a Stytch session will be created with a 60 minute duration. If you don't want
to use the Stytch session product, you can ignore the session fields in the response.
The type of this field is nilable +Integer+.
- session_custom_claims
Add a custom claims map to the Session being authenticated. Claims are only created if a Session is initialized by providing a value in
session_duration_minutes. Claims will be included on the Session object and in the JWT. To update a key in an existing Session, supply a new value. To delete a key, supply a null value. Custom claims made with reserved claims (iss,sub,aud,exp,nbf,iat,jti) will be ignored. Total custom claims size cannot exceed four kilobytes. The type of this field is nilableobject.- set_mfa_enrollment
Optionally sets the Member’s MFA enrollment status upon a successful authentication. If the Organization’s MFA policy is
REQUIRED_FOR_ALL, this field will be ignored. If this field is not passed in, the Member’smfa_enrolledboolean will not be affected. The options are:
enroll – sets the Member's mfa_enrolled boolean to true. The Member will be required to complete an MFA step upon subsequent logins to the Organization.
`unenroll`
- set_default_mfa
(no documentation yet) The type of this field is nilable
Boolean.- telemetry_id
If the
telemetry_idis passed, as part of this request, Stytch will call the Fingerprint Lookup API and store the associated fingerprints and IPGEO information for the Member. Your workspace must be enabled for Device Fingerprinting to use this feature. The type of this field is nilableString.
Returns:
An object with the following fields:
- request_id
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String.- member_id
Globally unique UUID that identifies a specific Member. The type of this field is
String.- member
The Member object The type of this field is
Member(+object+).- organization
The Organization object. The type of this field is
Organization(+object+).- session_token
A secret token for a given Stytch Session. The type of this field is
String.- session_jwt
The JSON Web Token (JWT) for a given Stytch Session. The type of this field is
String.- status_code
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer.- member_session
The Session object. The type of this field is nilable
MemberSession(+object+).- member_device
If a valid
telemetry_idwas passed in the request and the Fingerprint Lookup API returned results, themember_deviceresponse field will contain information about the member's device attributes. The type of this field is nilableDeviceInfo(+object+).
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/stytch/b2b_otp.rb', line 220 def authenticate( organization_id:, member_id:, code:, intermediate_session_token: nil, session_token: nil, session_jwt: nil, session_duration_minutes: nil, session_custom_claims: nil, set_mfa_enrollment: nil, set_default_mfa: nil, telemetry_id: nil ) headers = {} request = { organization_id: organization_id, member_id: member_id, code: code } request[:intermediate_session_token] = intermediate_session_token unless intermediate_session_token.nil? request[:session_token] = session_token unless session_token.nil? request[:session_jwt] = session_jwt unless session_jwt.nil? request[:session_duration_minutes] = session_duration_minutes unless session_duration_minutes.nil? request[:session_custom_claims] = session_custom_claims unless session_custom_claims.nil? request[:set_mfa_enrollment] = set_mfa_enrollment unless set_mfa_enrollment.nil? request[:set_default_mfa] = set_default_mfa unless set_default_mfa.nil? request[:telemetry_id] = telemetry_id unless telemetry_id.nil? post_request('/v1/b2b/otps/sms/authenticate', request, headers) end |
#send(organization_id:, member_id:, mfa_phone_number: nil, locale: nil, intermediate_session_token: nil, session_token: nil, session_jwt: nil) ⇒ Object
Send a One-Time Passcode (OTP) to a Member's phone number.
If the Member already has a phone number, the mfa_phone_number field is not needed; the endpoint will send an OTP to the number associated with the Member.
If the Member does not have a phone number, the endpoint will send an OTP to the mfa_phone_number provided and link the mfa_phone_number with the Member.
An error will be thrown if the Member already has a phone number and the provided mfa_phone_number does not match the existing one.
OTP codes expire after two minutes. Note that sending another OTP code before the first has expired will invalidate the first code.
If a Member has a phone number and is enrolled in MFA, then after a successful primary authentication event (e.g. email magic link or SSO login is complete), an SMS OTP will automatically be sent to their phone number. In that case, this endpoint should only be used for subsequent authentication events, such as prompting a Member for an OTP again after a period of inactivity.
If the Member already has an active MFA factor, then passing an intermediate session token, session token, or session JWT with the existing MFA factor on it is required to prevent bypassing MFA.
Otherwise, passing an intermediate session token, session token, or session JWT is not required, but if passed must match the member_id passed.
Cost to send SMS OTP
Before configuring SMS or WhatsApp OTPs, please review how Stytch bills the costs of international OTPs and understand how to protect your app against toll fraud.
Even when international SMS is enabled, we do not support sending SMS to countries on our Unsupported countries list.
Note: SMS to phone numbers outside of the US and Canada is disabled by default for customers who did not use SMS prior to October 2023. If you're interested in sending international SMS, please add those countries to your Project's allowlist via the Dashboard or Programmatic Workspace Actions, and add credit card details to your account.
Parameters:
- organization_id
Globally unique UUID that identifies a specific Organization. The
organization_idis critical to perform operations on an Organization, so be sure to preserve this value. You may also use the organization_slug or organization_external_id here as a convenience. The type of this field isString.- member_id
Globally unique UUID that identifies a specific Member. The
member_idis critical to perform operations on a Member, so be sure to preserve this value. You may use an external_id here if one is set for the member. The type of this field isString.- mfa_phone_number
The phone number to send the OTP to. If the Member already has a phone number, this argument is not needed. The type of this field is nilable
String.- locale
Used to determine which language to use when sending the user this delivery method. Parameter is an IETF BCP 47 language tag, e.g.
"en".
Currently supported languages are English ("en"), Spanish ("es"), French ("fr") and Brazilian Portuguese ("pt-br"); if no value is provided, the copy defaults to English.
Request support for additional languages here!
The type of this field is nilable +SendRequestLocale+ (string enum).
- intermediate_session_token
The Intermediate Session Token. This token does not necessarily belong to a specific instance of a Member, but represents a bag of factors that may be converted to a member session. The token can be used with the OTP SMS Authenticate endpoint, TOTP Authenticate endpoint, or Recovery Codes Recover endpoint to complete an MFA flow and log in to the Organization. The token has a default expiry of 10 minutes. It can also be used with the Exchange Intermediate Session endpoint to join a specific Organization that allows the factors represented by the intermediate session token; or the Create Organization via Discovery endpoint to create a new Organization and Member. Intermediate Session Tokens have a default expiry of 10 minutes. The type of this field is nilable
String.- session_token
A secret token for a given Stytch Session. The type of this field is nilable
String.- session_jwt
The JSON Web Token (JWT) for a given Stytch Session. The type of this field is nilable
String.
Returns:
An object with the following fields:
- request_id
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String.- member_id
Globally unique UUID that identifies a specific Member. The type of this field is
String.- member
The Member object The type of this field is
Member(+object+).- organization
The Organization object. The type of this field is
Organization(+object+).- status_code
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/stytch/b2b_otp.rb', line 97 def send( organization_id:, member_id:, mfa_phone_number: nil, locale: nil, intermediate_session_token: nil, session_token: nil, session_jwt: nil ) headers = {} request = { organization_id: organization_id, member_id: member_id } request[:mfa_phone_number] = mfa_phone_number unless mfa_phone_number.nil? request[:locale] = locale unless locale.nil? request[:intermediate_session_token] = intermediate_session_token unless intermediate_session_token.nil? request[:session_token] = session_token unless session_token.nil? request[:session_jwt] = session_jwt unless session_jwt.nil? post_request('/v1/b2b/otps/sms/send', request, headers) end |