Class: StytchB2B::Organizations::DeleteExternalIdRequestOptions

Inherits:
Object
  • Object
show all
Defined in:
lib/stytch/b2b_organizations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(authorization: nil) ⇒ DeleteExternalIdRequestOptions

Returns a new instance of DeleteExternalIdRequestOptions.



95
96
97
98
99
# File 'lib/stytch/b2b_organizations.rb', line 95

def initialize(
  authorization: nil
)
  @authorization = authorization
end

Instance Attribute Details

#authorizationObject

Optional authorization object. Pass in an active Stytch Member session token or session JWT and the request will be run using that member’s permissions.



93
94
95
# File 'lib/stytch/b2b_organizations.rb', line 93

def authorization
  @authorization
end

Instance Method Details

#to_headersObject



101
102
103
104
105
# File 'lib/stytch/b2b_organizations.rb', line 101

def to_headers
  headers = {}
  headers.merge!(@authorization.to_headers) if authorization
  headers
end