Class: StytchB2B::Organizations::Members::ConnectedApps::RevokeRequestOptions

Inherits:
Object
  • Object
show all
Defined in:
lib/stytch/b2b_organizations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(authorization: nil) ⇒ RevokeRequestOptions

Returns a new instance of RevokeRequestOptions.



2092
2093
2094
2095
2096
# File 'lib/stytch/b2b_organizations.rb', line 2092

def initialize(
  authorization: nil
)
  @authorization = authorization
end

Instance Attribute Details

#authorizationObject

Optional authorization object. Pass in an active Stytch Member session token or session JWT and the request will be run using that member’s permissions.



2090
2091
2092
# File 'lib/stytch/b2b_organizations.rb', line 2090

def authorization
  @authorization
end

Instance Method Details

#to_headersObject



2098
2099
2100
2101
2102
# File 'lib/stytch/b2b_organizations.rb', line 2098

def to_headers
  headers = {}
  headers.merge!(@authorization.to_headers) if authorization
  headers
end