Class: StytchB2B::Organizations::Members::CreateRequestOptions
- Inherits:
-
Object
- Object
- StytchB2B::Organizations::Members::CreateRequestOptions
- Defined in:
- lib/stytch/b2b_organizations.rb
Instance Attribute Summary collapse
-
#authorization ⇒ Object
Optional authorization object.
Instance Method Summary collapse
-
#initialize(authorization: nil) ⇒ CreateRequestOptions
constructor
A new instance of CreateRequestOptions.
- #to_headers ⇒ Object
Constructor Details
#initialize(authorization: nil) ⇒ CreateRequestOptions
Returns a new instance of CreateRequestOptions.
993 994 995 996 997 |
# File 'lib/stytch/b2b_organizations.rb', line 993 def initialize( authorization: nil ) @authorization = end |
Instance Attribute Details
#authorization ⇒ Object
Optional authorization object. Pass in an active Stytch Member session token or session JWT and the request will be run using that member’s permissions.
991 992 993 |
# File 'lib/stytch/b2b_organizations.rb', line 991 def @authorization end |
Instance Method Details
#to_headers ⇒ Object
999 1000 1001 1002 1003 |
# File 'lib/stytch/b2b_organizations.rb', line 999 def to_headers headers = {} headers.merge!(@authorization.to_headers) if headers end |