Class: StytchB2B::Organizations::Members::DeleteExternalIdRequestOptions
- Inherits:
-
Object
- Object
- StytchB2B::Organizations::Members::DeleteExternalIdRequestOptions
- Defined in:
- lib/stytch/b2b_organizations.rb
Instance Attribute Summary collapse
-
#authorization ⇒ Object
Optional authorization object.
Instance Method Summary collapse
-
#initialize(authorization: nil) ⇒ DeleteExternalIdRequestOptions
constructor
A new instance of DeleteExternalIdRequestOptions.
- #to_headers ⇒ Object
Constructor Details
#initialize(authorization: nil) ⇒ DeleteExternalIdRequestOptions
Returns a new instance of DeleteExternalIdRequestOptions.
974 975 976 977 978 |
# File 'lib/stytch/b2b_organizations.rb', line 974 def initialize( authorization: nil ) @authorization = end |
Instance Attribute Details
#authorization ⇒ Object
Optional authorization object. Pass in an active Stytch Member session token or session JWT and the request will be run using that member’s permissions.
972 973 974 |
# File 'lib/stytch/b2b_organizations.rb', line 972 def @authorization end |
Instance Method Details
#to_headers ⇒ Object
980 981 982 983 984 |
# File 'lib/stytch/b2b_organizations.rb', line 980 def to_headers headers = {} headers.merge!(@authorization.to_headers) if headers end |