Class: StytchB2B::Organizations::Members::DeleteMFAPhoneNumberRequestOptions

Inherits:
Object
  • Object
show all
Defined in:
lib/stytch/b2b_organizations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(authorization: nil) ⇒ DeleteMFAPhoneNumberRequestOptions

Returns a new instance of DeleteMFAPhoneNumberRequestOptions.



841
842
843
844
845
# File 'lib/stytch/b2b_organizations.rb', line 841

def initialize(
  authorization: nil
)
  @authorization = authorization
end

Instance Attribute Details

#authorizationObject

Optional authorization object. Pass in an active Stytch Member session token or session JWT and the request will be run using that member’s permissions.



839
840
841
# File 'lib/stytch/b2b_organizations.rb', line 839

def authorization
  @authorization
end

Instance Method Details

#to_headersObject



847
848
849
850
851
# File 'lib/stytch/b2b_organizations.rb', line 847

def to_headers
  headers = {}
  headers.merge!(@authorization.to_headers) if authorization
  headers
end