Class: StytchB2B::Organizations::Members::DeletePasswordRequestOptions

Inherits:
Object
  • Object
show all
Defined in:
lib/stytch/b2b_organizations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(authorization: nil) ⇒ DeletePasswordRequestOptions

Returns a new instance of DeletePasswordRequestOptions.



898
899
900
901
902
# File 'lib/stytch/b2b_organizations.rb', line 898

def initialize(
  authorization: nil
)
  @authorization = authorization
end

Instance Attribute Details

#authorizationObject

Optional authorization object. Pass in an active Stytch Member session token or session JWT and the request will be run using that member’s permissions.



896
897
898
# File 'lib/stytch/b2b_organizations.rb', line 896

def authorization
  @authorization
end

Instance Method Details

#to_headersObject



904
905
906
907
908
# File 'lib/stytch/b2b_organizations.rb', line 904

def to_headers
  headers = {}
  headers.merge!(@authorization.to_headers) if authorization
  headers
end