Class: StytchB2B::Organizations::Members::GetConnectedAppsRequestOptions

Inherits:
Object
  • Object
show all
Defined in:
lib/stytch/b2b_organizations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(authorization: nil) ⇒ GetConnectedAppsRequestOptions

Returns a new instance of GetConnectedAppsRequestOptions.



955
956
957
958
959
# File 'lib/stytch/b2b_organizations.rb', line 955

def initialize(
  authorization: nil
)
  @authorization = authorization
end

Instance Attribute Details

#authorizationObject

Optional authorization object. Pass in an active Stytch Member session token or session JWT and the request will be run using that member’s permissions.



953
954
955
# File 'lib/stytch/b2b_organizations.rb', line 953

def authorization
  @authorization
end

Instance Method Details

#to_headersObject



961
962
963
964
965
# File 'lib/stytch/b2b_organizations.rb', line 961

def to_headers
  headers = {}
  headers.merge!(@authorization.to_headers) if authorization
  headers
end