Class: StytchB2B::Passwords::Discovery
- Inherits:
-
Object
- Object
- StytchB2B::Passwords::Discovery
- Includes:
- Stytch::RequestHelper
- Defined in:
- lib/stytch/b2b_passwords.rb
Defined Under Namespace
Classes: Email
Instance Attribute Summary collapse
-
#email ⇒ Object
readonly
Returns the value of attribute email.
Instance Method Summary collapse
-
#authenticate(email_address:, password:) ⇒ Object
Authenticate an email/password combination in the discovery flow.
-
#initialize(connection) ⇒ Discovery
constructor
A new instance of Discovery.
Methods included from Stytch::RequestHelper
#delete_request, #get_request, #post_request, #put_request, #request_with_query_params
Constructor Details
#initialize(connection) ⇒ Discovery
Returns a new instance of Discovery.
965 966 967 968 969 |
# File 'lib/stytch/b2b_passwords.rb', line 965 def initialize(connection) @connection = connection @email = StytchB2B::Passwords::Discovery::Email.new(@connection) end |
Instance Attribute Details
#email ⇒ Object (readonly)
Returns the value of attribute email.
963 964 965 |
# File 'lib/stytch/b2b_passwords.rb', line 963 def email @email end |
Instance Method Details
#authenticate(email_address:, password:) ⇒ Object
Authenticate an email/password combination in the discovery flow. This authenticate flow is only valid for cross-org passwords use cases, and is not tied to a specific organization.
If you have breach detection during authentication enabled in your password strength policy and the member's credentials have appeared in the HaveIBeenPwned dataset, this endpoint will return a member_reset_password error even if the member enters a correct password. We force a password reset in this case to ensure that the member is the legitimate owner of the email address and not a malicious actor abusing the compromised credentials.
If successful, this endpoint will create a new intermediate session and return a list of discovered organizations that can be session exchanged into.
Parameters:
- email_address
The email address of the Member. The type of this field is
String.- password
The password to authenticate, reset, or set for the first time. Any UTF8 character is allowed, e.g. spaces, emojis, non-English characters, etc. The type of this field is
String.
Returns:
An object with the following fields:
- request_id
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String.- email_address
The email address. The type of this field is
String.- intermediate_session_token
The returned Intermediate Session Token contains a password factor associated with the Member. If this value is non-empty, the member must complete an MFA step to finish logging in to the Organization. The token can be used with the OTP SMS Authenticate endpoint, TOTP Authenticate endpoint, or Recovery Codes Recover endpoint to complete an MFA flow and log in to the Organization. The token has a default expiry of 10 minutes. Password factors are not transferable between Organizations, so the intermediate session token is not valid for use with discovery endpoints. The type of this field is
String.- discovered_organizations
An array of
discovered_organizationobjects tied to theintermediate_session_token,session_token, orsession_jwt. See the Discovered Organization Object for complete details.
Note that Organizations will only appear here under any of the following conditions:
1. The end user is already a Member of the Organization.
2. The end user is invited to the Organization.
3. The end user can join the Organization because:
a) The Organization allows JIT provisioning.
b) The Organizations' allowed domains list contains the Member's email domain.
c) The Organization has at least one other Member with a verified email address with the same domain as the end user (to prevent phishing attacks).
The type of this field is list of +DiscoveredOrganization+ (+object+).
- status_code
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer.- intermediate_session_token_expires_at
(no documentation yet) The type of this field is nilable
String.
1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 |
# File 'lib/stytch/b2b_passwords.rb', line 1016 def authenticate( email_address:, password: ) headers = {} request = { email_address: email_address, password: password } post_request('/v1/b2b/passwords/discovery/authenticate', request, headers) end |