Class: StytchB2B::SSO
- Inherits:
-
Object
- Object
- StytchB2B::SSO
- Includes:
- Stytch::RequestHelper
- Defined in:
- lib/stytch/b2b_sso.rb
Defined Under Namespace
Classes: DeleteConnectionRequestOptions, External, GetConnectionsRequestOptions, OIDC, SAML
Instance Attribute Summary collapse
-
#external ⇒ Object
readonly
Returns the value of attribute external.
-
#oidc ⇒ Object
readonly
Returns the value of attribute oidc.
-
#saml ⇒ Object
readonly
Returns the value of attribute saml.
Instance Method Summary collapse
-
#authenticate(sso_token:, pkce_code_verifier: nil, session_token: nil, session_jwt: nil, session_duration_minutes: nil, session_custom_claims: nil, locale: nil, intermediate_session_token: nil, telemetry_id: nil) ⇒ Object
Authenticate a user given a token.
-
#delete_connection(organization_id:, connection_id:, method_options: nil) ⇒ Object
Delete an existing SSO connection.
-
#get_connections(organization_id:, method_options: nil) ⇒ Object
Get all SSO Connections owned by the organization.
-
#initialize(connection) ⇒ SSO
constructor
A new instance of SSO.
Methods included from Stytch::RequestHelper
#delete_request, #get_request, #post_request, #put_request, #request_with_query_params
Constructor Details
#initialize(connection) ⇒ SSO
Returns a new instance of SSO.
54 55 56 57 58 59 60 |
# File 'lib/stytch/b2b_sso.rb', line 54 def initialize(connection) @connection = connection @oidc = StytchB2B::SSO::OIDC.new(@connection) @saml = StytchB2B::SSO::SAML.new(@connection) @external = StytchB2B::SSO::External.new(@connection) end |
Instance Attribute Details
#external ⇒ Object (readonly)
Returns the value of attribute external.
52 53 54 |
# File 'lib/stytch/b2b_sso.rb', line 52 def external @external end |
#oidc ⇒ Object (readonly)
Returns the value of attribute oidc.
52 53 54 |
# File 'lib/stytch/b2b_sso.rb', line 52 def oidc @oidc end |
#saml ⇒ Object (readonly)
Returns the value of attribute saml.
52 53 54 |
# File 'lib/stytch/b2b_sso.rb', line 52 def saml @saml end |
Instance Method Details
#authenticate(sso_token:, pkce_code_verifier: nil, session_token: nil, session_jwt: nil, session_duration_minutes: nil, session_custom_claims: nil, locale: nil, intermediate_session_token: nil, telemetry_id: nil) ⇒ Object
Authenticate a user given a token.
This endpoint verifies that the user completed the SSO Authentication flow by verifying that the token is valid and hasn't expired.
Provide the session_duration_minutes parameter to set the lifetime of the session.
If the session_duration_minutes parameter is not specified, a Stytch session will be created with a 60 minute duration.
To link this authentication event to an existing Stytch session, include either the session_token or session_jwt param.
If the Member is required to complete MFA to log in to the Organization, the returned value of member_authenticated will be false, and an intermediate_session_token will be returned.
The intermediate_session_token can be passed into the OTP SMS Authenticate endpoint, TOTP Authenticate endpoint,
or Recovery Codes Recover endpoint to complete the MFA step and acquire a full member session.
The session_duration_minutes and session_custom_claims parameters will be ignored.
If a valid session_token or session_jwt is passed in, the Member will not be required to complete an MFA step.
Parameters:
- sso_token
The token to authenticate. The type of this field is
String.- pkce_code_verifier
A base64url encoded one time secret used to validate that the request starts and ends on the same device. The type of this field is nilable
String.- session_token
The
session_tokenbelonging to the member that you wish to associate the email with. The type of this field is nilableString.- session_jwt
The
session_jwtbelonging to the member that you wish to associate the email with. The type of this field is nilableString.- session_duration_minutes
Set the session lifetime to be this many minutes from now. This will start a new session if one doesn't already exist, returning both an opaque
session_tokenandsession_jwtfor this session. Remember that thesession_jwtwill have a fixed lifetime of five minutes regardless of the underlying session duration, and will need to be refreshed over time.
This value must be a minimum of 5 and a maximum of 527040 minutes (366 days).
If a `session_token` or `session_jwt` is provided then a successful authentication will continue to extend the session this many minutes.
If the `session_duration_minutes` parameter is not specified, a Stytch session will be created with a 60 minute duration. If you don't want
to use the Stytch session product, you can ignore the session fields in the response.
The type of this field is nilable +Integer+.
- session_custom_claims
Add a custom claims map to the Session being authenticated. Claims are only created if a Session is initialized by providing a value in
session_duration_minutes. Claims will be included on the Session object and in the JWT. To update a key in an existing Session, supply a new value. To delete a key, supply a null value. Custom claims made with reserved claims (iss,sub,aud,exp,nbf,iat,jti) will be ignored. Total custom claims size cannot exceed four kilobytes. The type of this field is nilableobject.- locale
If the Member needs to complete an MFA step, and the Member has a phone number, this endpoint will pre-emptively send a one-time passcode (OTP) to the Member's phone number. The locale argument will be used to determine which language to use when sending the passcode.
Parameter is an IETF BCP 47 language tag, e.g. "en".
Currently supported languages are English ("en"), Spanish ("es"), and Brazilian Portuguese ("pt-br"); if no value is provided, the copy defaults to English.
Request support for additional languages here!
The type of this field is nilable +AuthenticateRequestLocale+ (string enum).
- intermediate_session_token
Adds this primary authentication factor to the intermediate session token. If the resulting set of factors satisfies the organization's primary authentication requirements and MFA requirements, the intermediate session token will be consumed and converted to a member session. If not, the same intermediate session token will be returned. The type of this field is nilable
String.- telemetry_id
If the
telemetry_idis passed, as part of this request, Stytch will call the Fingerprint Lookup API and store the associated fingerprints and IPGEO information for the Member. Your workspace must be enabled for Device Fingerprinting to use this feature. The type of this field is nilableString.
Returns:
An object with the following fields:
- request_id
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String.- member_id
Globally unique UUID that identifies a specific Member. The type of this field is
String.- organization_id
Globally unique UUID that identifies a specific Organization. The
organization_idis critical to perform operations on an Organization, so be sure to preserve this value. The type of this field isString.- member
The Member object The type of this field is
Member(+object+).- session_token
A secret token for a given Stytch Session. The type of this field is
String.- session_jwt
The JSON Web Token (JWT) for a given Stytch Session. The type of this field is
String.- reset_session
This field is deprecated. The type of this field is
Boolean.- organization
The Organization object. The type of this field is
Organization(+object+).- intermediate_session_token
The returned Intermediate Session Token contains an SSO factor associated with the Member. If this value is non-empty, the member must complete an MFA step to finish logging in to the Organization. The token can be used with the OTP SMS Authenticate endpoint, TOTP Authenticate endpoint, or Recovery Codes Recover endpoint to complete an MFA flow and log in to the Organization. The token has a default expiry of 10 minutes. SSO factors are not transferable between Organizations, so the intermediate session token is not valid for use with discovery endpoints. The type of this field is
String.- member_authenticated
Indicates whether the Member is fully authenticated. If false, the Member needs to complete an MFA step to log in to the Organization. The type of this field is
Boolean.- status_code
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer.- member_session
The Session object. The type of this field is nilable
MemberSession(+object+).- mfa_required
Information about the MFA requirements of the Organization and the Member's options for fulfilling MFA. The type of this field is nilable
MfaRequired(+object+).- primary_required
(no documentation yet) The type of this field is nilable
PrimaryRequired(+object+).- member_device
If a valid
telemetry_idwas passed in the request and the Fingerprint Lookup API returned results, themember_deviceresponse field will contain information about the member's device attributes. The type of this field is nilableDeviceInfo(+object+).- intermediate_session_token_expires_at
(no documentation yet) The type of this field is nilable
String.
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/stytch/b2b_sso.rb', line 245 def authenticate( sso_token:, pkce_code_verifier: nil, session_token: nil, session_jwt: nil, session_duration_minutes: nil, session_custom_claims: nil, locale: nil, intermediate_session_token: nil, telemetry_id: nil ) headers = {} request = { sso_token: sso_token } request[:pkce_code_verifier] = pkce_code_verifier unless pkce_code_verifier.nil? request[:session_token] = session_token unless session_token.nil? request[:session_jwt] = session_jwt unless session_jwt.nil? request[:session_duration_minutes] = session_duration_minutes unless session_duration_minutes.nil? request[:session_custom_claims] = session_custom_claims unless session_custom_claims.nil? request[:locale] = locale unless locale.nil? request[:intermediate_session_token] = intermediate_session_token unless intermediate_session_token.nil? request[:telemetry_id] = telemetry_id unless telemetry_id.nil? post_request('/v1/b2b/sso/authenticate', request, headers) end |
#delete_connection(organization_id:, connection_id:, method_options: nil) ⇒ Object
Delete an existing SSO connection.
Parameters:
- organization_id
The organization ID that the SSO connection belongs to. You may also use the organization_slug or organization_external_id here as a convenience. The type of this field is
String.- connection_id
The ID of the SSO connection. SAML, OIDC, and External connection IDs can be provided. The type of this field is
String.
Returns:
An object with the following fields:
- request_id
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String.- connection_id
The
connection_idthat was deleted as part of the delete request. The type of this field isString.- status_code
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer.
Method Options:
This method supports an optional StytchB2B::SSO::DeleteConnectionRequestOptions object which will modify the headers sent in the HTTP request.
124 125 126 127 128 129 130 131 132 |
# File 'lib/stytch/b2b_sso.rb', line 124 def delete_connection( organization_id:, connection_id:, method_options: nil ) headers = {} headers = headers.merge(.to_headers) unless .nil? delete_request("/v1/b2b/sso/#{organization_id}/connections/#{connection_id}", headers) end |
#get_connections(organization_id:, method_options: nil) ⇒ Object
Get all SSO Connections owned by the organization.
Parameters:
- organization_id
Globally unique UUID that identifies a specific Organization. The
organization_idis critical to perform operations on an Organization, so be sure to preserve this value. You may also use the organization_slug or organization_external_id here as a convenience. The type of this field isString.
Returns:
An object with the following fields:
- request_id
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String.- saml_connections
The list of SAML Connections owned by this organization. The type of this field is list of
SAMLConnection(+object+).- oidc_connections
The list of OIDC Connections owned by this organization. The type of this field is list of
OIDCConnection(+object+).- external_connections
The list of External Connections owned by this organization. The type of this field is list of
Connection(+object+).- status_code
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer.
Method Options:
This method supports an optional StytchB2B::SSO::GetConnectionsRequestOptions object which will modify the headers sent in the HTTP request.
89 90 91 92 93 94 95 96 97 98 |
# File 'lib/stytch/b2b_sso.rb', line 89 def get_connections( organization_id:, method_options: nil ) headers = {} headers = headers.merge(.to_headers) unless .nil? query_params = {} request = request_with_query_params("/v1/b2b/sso/#{organization_id}", query_params) get_request(request, headers) end |