Class: StytchB2B::SSO::SAML::CreateConnectionRequestOptions

Inherits:
Object
  • Object
show all
Defined in:
lib/stytch/b2b_sso.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(authorization: nil) ⇒ CreateConnectionRequestOptions

Returns a new instance of CreateConnectionRequestOptions.



482
483
484
485
486
# File 'lib/stytch/b2b_sso.rb', line 482

def initialize(
  authorization: nil
)
  @authorization = authorization
end

Instance Attribute Details

#authorizationObject

Optional authorization object. Pass in an active Stytch Member session token or session JWT and the request will be run using that member’s permissions.



480
481
482
# File 'lib/stytch/b2b_sso.rb', line 480

def authorization
  @authorization
end

Instance Method Details

#to_headersObject



488
489
490
491
492
# File 'lib/stytch/b2b_sso.rb', line 488

def to_headers
  headers = {}
  headers.merge!(@authorization.to_headers) if authorization
  headers
end