Class: Stytch::Passwords
- Inherits:
-
Object
- Object
- Stytch::Passwords
- Includes:
- RequestHelper
- Defined in:
- lib/stytch/passwords.rb
Defined Under Namespace
Classes: Email, ExistingPassword, Sessions
Instance Attribute Summary collapse
-
#email ⇒ Object
readonly
Returns the value of attribute email.
-
#existing_password ⇒ Object
readonly
Returns the value of attribute existing_password.
-
#sessions ⇒ Object
readonly
Returns the value of attribute sessions.
Instance Method Summary collapse
-
#authenticate(email:, password:, session_token: nil, session_duration_minutes: nil, session_jwt: nil, session_custom_claims: nil, telemetry_id: nil) ⇒ Object
Authenticate a user with their email address and password.
-
#create(email:, password:, session_duration_minutes: nil, session_custom_claims: nil, trusted_metadata: nil, untrusted_metadata: nil, name: nil, telemetry_id: nil) ⇒ Object
Create a new user with a password.
-
#initialize(connection) ⇒ Passwords
constructor
A new instance of Passwords.
-
#migrate(email:, hash:, hash_type:, md_5_config: nil, argon_2_config: nil, sha_1_config: nil, sha_512_config: nil, scrypt_config: nil, pbkdf_2_config: nil, trusted_metadata: nil, untrusted_metadata: nil, set_email_verified: nil, name: nil, phone_number: nil, set_phone_number_verified: nil, external_id: nil, roles: nil) ⇒ Object
Adds an existing password to a User’s email that doesn’t have a password yet.
-
#strength_check(password:, email: nil) ⇒ Object
This API allows you to check whether or not the user’s provided password is valid, and to provide feedback to the user on how to increase the strength of their password.
Methods included from RequestHelper
#delete_request, #get_request, #post_request, #put_request, #request_with_query_params
Constructor Details
#initialize(connection) ⇒ Passwords
Returns a new instance of Passwords.
16 17 18 19 20 21 22 |
# File 'lib/stytch/passwords.rb', line 16 def initialize(connection) @connection = connection @email = Stytch::Passwords::Email.new(@connection) @existing_password = Stytch::Passwords::ExistingPassword.new(@connection) @sessions = Stytch::Passwords::Sessions.new(@connection) end |
Instance Attribute Details
#email ⇒ Object (readonly)
Returns the value of attribute email.
14 15 16 |
# File 'lib/stytch/passwords.rb', line 14 def email @email end |
#existing_password ⇒ Object (readonly)
Returns the value of attribute existing_password.
14 15 16 |
# File 'lib/stytch/passwords.rb', line 14 def existing_password @existing_password end |
#sessions ⇒ Object (readonly)
Returns the value of attribute sessions.
14 15 16 |
# File 'lib/stytch/passwords.rb', line 14 def sessions @sessions end |
Instance Method Details
#authenticate(email:, password:, session_token: nil, session_duration_minutes: nil, session_jwt: nil, session_custom_claims: nil, telemetry_id: nil) ⇒ Object
Authenticate a user with their email address and password. This endpoint verifies that the user has a password currently set, and that the entered password is correct. There are two instances where the endpoint will return a ‘reset_password` error even if they enter their previous password:
One: The user’s credentials appeared in the HaveIBeenPwned dataset. We force a password reset to ensure that the user is the legitimate owner of the email address, and not a malicious actor abusing the compromised credentials.
Two: A user that has previously authenticated with email/password uses a passwordless authentication method tied to the same email address (e.g. Magic Links, Google OAuth) for the first time. Any subsequent email/password authentication attempt will result in this error. We force a password reset in this instance in order to safely deduplicate the account by email address, without introducing the risk of a pre-hijack account takeover attack.
Imagine a bad actor creates many accounts using passwords and the known email addresses of their victims. If a victim comes to the site and logs in for the first time with an email-based passwordless authentication method then both the victim and the bad actor have credentials to access to the same account. To prevent this, any further email/password login attempts first require a password reset which can only be accomplished by someone with access to the underlying email address.
Parameters:
-
The email address of the end user. The type of this field is
String. - password
-
The password for the user. Any UTF8 character is allowed, e.g. spaces, emojis, non-English characters, etc. The type of this field is
String. - session_token
-
The ‘session_token` associated with a User’s existing Session. The type of this field is nilable
String. - session_duration_minutes
-
Set the session lifetime to be this many minutes from now. This will start a new session if one doesn’t already exist, returning both an opaque ‘session_token` and `session_jwt` for this session. Remember that the `session_jwt` will have a fixed lifetime of five minutes regardless of the underlying session duration, and will need to be refreshed over time.
This value must be a minimum of 5 and a maximum of 527040 minutes (366 days).
If a ‘session_token` or `session_jwt` is provided then a successful authentication will continue to extend the session this many minutes.
If the ‘session_duration_minutes` parameter is not specified, a Stytch session will not be created. The type of this field is nilable
Integer. - session_jwt
-
The ‘session_jwt` associated with a User’s existing Session. The type of this field is nilable
String. - session_custom_claims
-
Add a custom claims map to the Session being authenticated. Claims are only created if a Session is initialized by providing a value in ‘session_duration_minutes`. Claims will be included on the Session object and in the JWT. To update a key in an existing Session, supply a new value. To delete a key, supply a null value.
Custom claims made with reserved claims (“iss”, “sub”, “aud”, “exp”, “nbf”, “iat”, “jti”) will be ignored. Total custom claims size cannot exceed four kilobytes. The type of this field is nilable
object. - telemetry_id
-
If the ‘telemetry_id` is passed, as part of this request, Stytch will call the [Fingerprint Lookup API](stytch.com/docs/fraud/api/fingerprint-lookup) and store the associated fingerprints and IPGEO information for the User. Your workspace must be enabled for Device Fingerprinting to use this feature. The type of this field is nilable
String.
Returns:
An object with the following fields:
- request_id
-
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String. - user_id
-
The unique ID of the affected User. The type of this field is
String. - session_token
-
A secret token for a given Stytch Session. The type of this field is
String. - session_jwt
-
The JSON Web Token (JWT) for a given Stytch Session. The type of this field is
String. - user
-
The ‘user` object affected by this API call. See the [Get user endpoint](stytch.com/docs/api/get-user) for complete response field details. The type of this field is
User(object). - status_code
-
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer. - session
-
If you initiate a Session, by including ‘session_duration_minutes` in your authenticate call, you’ll receive a full Session object in the response.
See [Session object](stytch.com/docs/api/session-object) for complete response fields.
The type of this field is nilable
Session(object). - user_device
-
If a valid ‘telemetry_id` was passed in the request and the [Fingerprint Lookup API](stytch.com/docs/fraud/api/fingerprint-lookup) returned results, the `user_device` response field will contain information about the user’s device attributes. The type of this field is nilable
DeviceInfo(object).
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/stytch/passwords.rb', line 195 def authenticate( email:, password:, session_token: nil, session_duration_minutes: nil, session_jwt: nil, session_custom_claims: nil, telemetry_id: nil ) headers = {} request = { email: email, password: password } request[:session_token] = session_token unless session_token.nil? request[:session_duration_minutes] = session_duration_minutes unless session_duration_minutes.nil? request[:session_jwt] = session_jwt unless session_jwt.nil? request[:session_custom_claims] = session_custom_claims unless session_custom_claims.nil? request[:telemetry_id] = telemetry_id unless telemetry_id.nil? post_request('/v1/passwords/authenticate', request, headers) end |
#create(email:, password:, session_duration_minutes: nil, session_custom_claims: nil, trusted_metadata: nil, untrusted_metadata: nil, name: nil, telemetry_id: nil) ⇒ Object
Create a new user with a password. If ‘session_duration_minutes` is specified, a new session will be started as well.
If a user with this email already exists in your Stytch project, this endpoint will return a ‘duplicate_email` error. To add a password to an existing passwordless user, you’ll need to either call the [Migrate password endpoint](stytch.com/docs/api/password-migrate) or prompt the user to complete one of our password reset flows.
This endpoint will return an error if the password provided does not meet our strength requirements, which you can check beforehand via the [Password strength check endpoint](stytch.com/docs/api/password-strength-check).
When creating new Passwords users, it’s good practice to enforce an email verification flow. We’d recommend checking out our [Email verification guide](stytch.com/docs/guides/passwords/email-verification/overview) for more information.
Parameters:
-
The email address of the end user. The type of this field is
String. - password
-
The password for the user. Any UTF8 character is allowed, e.g. spaces, emojis, non-English characters, etc. The type of this field is
String. - session_duration_minutes
-
Set the session lifetime to be this many minutes from now. This will start a new session if one doesn’t already exist, returning both an opaque ‘session_token` and `session_jwt` for this session. Remember that the `session_jwt` will have a fixed lifetime of five minutes regardless of the underlying session duration, and will need to be refreshed over time.
This value must be a minimum of 5 and a maximum of 527040 minutes (366 days).
If a ‘session_token` or `session_jwt` is provided then a successful authentication will continue to extend the session this many minutes.
If the ‘session_duration_minutes` parameter is not specified, a Stytch session will not be created. The type of this field is nilable
Integer. - session_custom_claims
-
Add a custom claims map to the Session being authenticated. Claims are only created if a Session is initialized by providing a value in ‘session_duration_minutes`. Claims will be included on the Session object and in the JWT. To update a key in an existing Session, supply a new value. To delete a key, supply a null value.
Custom claims made with reserved claims (“iss”, “sub”, “aud”, “exp”, “nbf”, “iat”, “jti”) will be ignored. Total custom claims size cannot exceed four kilobytes. The type of this field is nilable
object. - trusted_metadata
-
The ‘trusted_metadata` field contains an arbitrary JSON object of application-specific data. See the [Metadata](stytch.com/docs/api/metadata) reference for complete field behavior details. The type of this field is nilable
object. - untrusted_metadata
-
The ‘untrusted_metadata` field contains an arbitrary JSON object of application-specific data. Untrusted metadata can be edited by end users directly via the SDK, and **cannot be used to store critical information.** See the [Metadata](stytch.com/docs/api/metadata) reference for complete field behavior details. The type of this field is nilable
object. - name
-
The name of the user. Each field in the name object is optional. The type of this field is nilable
Name(object). - telemetry_id
-
If the ‘telemetry_id` is passed, as part of this request, Stytch will call the [Fingerprint Lookup API](stytch.com/docs/fraud/api/fingerprint-lookup) and store the associated fingerprints and IPGEO information for the User. Your workspace must be enabled for Device Fingerprinting to use this feature. The type of this field is nilable
String.
Returns:
An object with the following fields:
- request_id
-
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String. - user_id
-
The unique ID of the affected User. The type of this field is
String. - email_id
-
The unique ID of a specific email address. The type of this field is
String. - session_token
-
A secret token for a given Stytch Session. The type of this field is
String. - session_jwt
-
The JSON Web Token (JWT) for a given Stytch Session. The type of this field is
String. - user
-
The ‘user` object affected by this API call. See the [Get user endpoint](stytch.com/docs/api/get-user) for complete response field details. The type of this field is
User(object). - status_code
-
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer. - session
-
If you initiate a Session, by including ‘session_duration_minutes` in your authenticate call, you’ll receive a full Session object in the response.
See [Session object](stytch.com/docs/api/session-object) for complete response fields.
The type of this field is nilable
Session(object). - user_device
-
If a valid ‘telemetry_id` was passed in the request and the [Fingerprint Lookup API](stytch.com/docs/fraud/api/fingerprint-lookup) returned results, the `user_device` response field will contain information about the user’s device attributes. The type of this field is nilable
DeviceInfo(object).
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/stytch/passwords.rb', line 100 def create( email:, password:, session_duration_minutes: nil, session_custom_claims: nil, trusted_metadata: nil, untrusted_metadata: nil, name: nil, telemetry_id: nil ) headers = {} request = { email: email, password: password } request[:session_duration_minutes] = session_duration_minutes unless session_duration_minutes.nil? request[:session_custom_claims] = session_custom_claims unless session_custom_claims.nil? request[:trusted_metadata] = unless .nil? request[:untrusted_metadata] = unless .nil? request[:name] = name unless name.nil? request[:telemetry_id] = telemetry_id unless telemetry_id.nil? post_request('/v1/passwords', request, headers) end |
#migrate(email:, hash:, hash_type:, md_5_config: nil, argon_2_config: nil, sha_1_config: nil, sha_512_config: nil, scrypt_config: nil, pbkdf_2_config: nil, trusted_metadata: nil, untrusted_metadata: nil, set_email_verified: nil, name: nil, phone_number: nil, set_phone_number_verified: nil, external_id: nil, roles: nil) ⇒ Object
Adds an existing password to a User’s email that doesn’t have a password yet. We support migrating users from passwords stored with ‘bcrypt`, `scrypt`, `argon2`, `MD-5`, `SHA-1`, `SHA-512`, or `PBKDF2`. This endpoint has a rate limit of 100 requests per second.
Parameters:
-
The email address of the end user. The type of this field is
String. - hash
-
The password hash. For a Scrypt or PBKDF2 hash, the hash needs to be a base64 encoded string. The type of this field is
String. - hash_type
-
The password hash used. Currently ‘bcrypt`, `scrypt`, `argon_2i`, `argon_2id`, `md_5`, `sha_1`, `sha_512`, and `pbkdf_2` are supported. The type of this field is
MigrateRequestHashType(string enum). - md_5_config
-
Optional parameters for MD-5 hash types. The type of this field is nilable
MD5Config(object). - argon_2_config
-
Required parameters if the argon2 hex form, as opposed to the encoded form, is supplied. The type of this field is nilable
Argon2Config(object). - sha_1_config
-
Optional parameters for SHA-1 hash types. The type of this field is nilable
SHA1Config(object). - sha_512_config
-
Optional parameters for SHA-512 hash types. The type of this field is nilable
SHA512Config(object). - scrypt_config
-
Required parameters if the scrypt is not provided in a [PHC encoded form](github.com/P-H-C/phc-string-format/blob/master/phc-sf-spec.md#phc-string-format). The type of this field is nilable
ScryptConfig(object). - pbkdf_2_config
-
Required additional parameters for PBKDF2 hash keys. The type of this field is nilable
PBKDF2Config(object). - trusted_metadata
-
The ‘trusted_metadata` field contains an arbitrary JSON object of application-specific data. See the [Metadata](stytch.com/docs/api/metadata) reference for complete field behavior details. The type of this field is nilable
object. - untrusted_metadata
-
The ‘untrusted_metadata` field contains an arbitrary JSON object of application-specific data. Untrusted metadata can be edited by end users directly via the SDK, and **cannot be used to store critical information.** See the [Metadata](stytch.com/docs/api/metadata) reference for complete field behavior details. The type of this field is nilable
object. - set_email_verified
-
Whether to set the user’s email as verified. This is a dangerous field, incorrect use may lead to users getting erroneously
deduplicated into one User object. This flag should only be set if you can attest that the user owns the email address in question.The type of this field is nilable
Boolean. - name
-
The name of the user. Each field in the name object is optional. The type of this field is nilable
Name(object). - phone_number
-
The phone number of the user. The phone number should be in E.164 format (i.e. +1XXXXXXXXXX). The type of this field is nilable
String. - set_phone_number_verified
-
Whether to set the user’s phone number as verified. This is a dangerous field, this flag should only be set if you can attest that
the user owns the phone number in question.The type of this field is nilable
Boolean. - external_id
-
If a new user is created, this will set an identifier that can be used in API calls wherever a user_id is expected. This is a string consisting of alphanumeric, ‘.`, `_`, `-`, or `|` characters with a maximum length of 128 characters. The type of this field is nilable
String. - roles
-
Roles to explicitly assign to this User.
See the [RBAC guide](https://stytch.com/docs/guides/rbac/role-assignment) for more information about role assignment.The type of this field is nilable list of
String.
Returns:
An object with the following fields:
- request_id
-
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String. - user_id
-
The unique ID of the affected User. The type of this field is
String. - email_id
-
The unique ID of a specific email address. The type of this field is
String. - user_created
-
In ‘login_or_create` endpoints, this field indicates whether or not a User was just created. The type of this field is
Boolean. - user
-
The ‘user` object affected by this API call. See the [Get user endpoint](stytch.com/docs/api/get-user) for complete response field details. The type of this field is
User(object). - status_code
-
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer.
357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/stytch/passwords.rb', line 357 def migrate( email:, hash:, hash_type:, md_5_config: nil, argon_2_config: nil, sha_1_config: nil, sha_512_config: nil, scrypt_config: nil, pbkdf_2_config: nil, trusted_metadata: nil, untrusted_metadata: nil, set_email_verified: nil, name: nil, phone_number: nil, set_phone_number_verified: nil, external_id: nil, roles: nil ) headers = {} request = { email: email, hash: hash, hash_type: hash_type } request[:md_5_config] = md_5_config unless md_5_config.nil? request[:argon_2_config] = argon_2_config unless argon_2_config.nil? request[:sha_1_config] = sha_1_config unless sha_1_config.nil? request[:sha_512_config] = sha_512_config unless sha_512_config.nil? request[:scrypt_config] = scrypt_config unless scrypt_config.nil? request[:pbkdf_2_config] = pbkdf_2_config unless pbkdf_2_config.nil? request[:trusted_metadata] = unless .nil? request[:untrusted_metadata] = unless .nil? request[:set_email_verified] = set_email_verified unless set_email_verified.nil? request[:name] = name unless name.nil? request[:phone_number] = phone_number unless phone_number.nil? request[:set_phone_number_verified] = set_phone_number_verified unless set_phone_number_verified.nil? request[:external_id] = external_id unless external_id.nil? request[:roles] = roles unless roles.nil? post_request('/v1/passwords/migrate', request, headers) end |
#strength_check(password:, email: nil) ⇒ Object
This API allows you to check whether or not the user’s provided password is valid, and to provide feedback to the user on how to increase the strength of their password.
This endpoint adapts to your Project’s password strength configuration. If you’re using [zxcvbn](stytch.com/docs/guides/passwords/strength-policy), the default, your passwords are considered valid if the strength score is >= 3. If you’re using [LUDS](stytch.com/docs/guides/passwords/strength-policy), your passwords are considered valid if they meet the requirements that you’ve set with Stytch. You may update your password strength configuration in the [Stytch Dashboard](stytch.com/dashboard/password-strength-config).
### Password feedback
The ‘feedback` object contains relevant fields for you to relay feedback to users that failed to create a strong enough password.
If you’re using zxcvbn, the ‘feedback` object will contain `warning` and `suggestions` for any password that does not meet the zxcvbn strength requirements. You can return these strings directly to the user to help them craft a strong password.
If you’re using LUDS, the ‘feedback` object will contain an object named `luds_requirements` which contain a collection of fields that the user failed or passed. You’ll want to prompt the user to create a password that meets all of the requirements that they failed.
Parameters:
- password
-
The password for the user. Any UTF8 character is allowed, e.g. spaces, emojis, non-English characters, etc. The type of this field is
String. -
The email address of the end user. The type of this field is nilable
String.
Returns:
An object with the following fields:
- request_id
-
Globally unique UUID that is returned with every API call. This value is important to log for debugging purposes; we may ask for this value to help identify a specific API call when helping you debug an issue. The type of this field is
String. - valid_password
-
Returns ‘true` if the password passes our password validation. We offer two validation options, [zxcvbn](stytch.com/docs/guides/passwords/strength-policy) is the default option which offers a high level of sophistication. We also offer [LUDS](stytch.com/docs/guides/passwords/strength-policy) which is less sophisticated but easier to understand. If an email address is included in the call we also require that the password hasn’t been compromised using built-in breach detection powered by [HaveIBeenPwned](haveibeenpwned.com/). The type of this field is
Boolean. - score
-
The score of the password determined by [zxcvbn](github.com/dropbox/zxcvbn). Values will be between 1 and 4, a 3 or greater is required to pass validation. The type of this field is
Integer. - breached_password
-
Returns ‘true` if the password has been breached. Powered by [HaveIBeenPwned](haveibeenpwned.com/). The type of this field is
Boolean. - strength_policy
-
The strength policy type enforced, either ‘zxcvbn` or `luds`. The type of this field is
String. - breach_detection_on_create
-
Will return ‘true` if breach detection will be evaluated. By default this option is enabled. This option can be disabled in the [dashboard](stytch.com/dashboard/password-strength-config#breach-detection). If this value is `false` then `breached_password` will always be `false` as well. The type of this field is
Boolean. - status_code
-
The HTTP status code of the response. Stytch follows standard HTTP response status code patterns, e.g. 2XX values equate to success, 3XX values are redirects, 4XX are client errors, and 5XX are server errors. The type of this field is
Integer. - feedback
-
Feedback for how to improve the password’s strength [HaveIBeenPwned](haveibeenpwned.com/). The type of this field is nilable
Feedback(object).
265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/stytch/passwords.rb', line 265 def strength_check( password:, email: nil ) headers = {} request = { password: password } request[:email] = email unless email.nil? post_request('/v1/passwords/strength_check', request, headers) end |