Class: StytchB2B::Organizations::Members::ConnectedApps::RevokeRequestOptions
- Inherits:
-
Object
- Object
- StytchB2B::Organizations::Members::ConnectedApps::RevokeRequestOptions
- Defined in:
- lib/stytch/b2b_organizations.rb
Instance Attribute Summary collapse
-
#authorization ⇒ Object
Optional authorization object.
Instance Method Summary collapse
-
#initialize(authorization: nil) ⇒ RevokeRequestOptions
constructor
A new instance of RevokeRequestOptions.
- #to_headers ⇒ Object
Constructor Details
#initialize(authorization: nil) ⇒ RevokeRequestOptions
Returns a new instance of RevokeRequestOptions.
2092 2093 2094 2095 2096 |
# File 'lib/stytch/b2b_organizations.rb', line 2092 def initialize( authorization: nil ) @authorization = end |
Instance Attribute Details
#authorization ⇒ Object
Optional authorization object. Pass in an active Stytch Member session token or session JWT and the request will be run using that member’s permissions.
2090 2091 2092 |
# File 'lib/stytch/b2b_organizations.rb', line 2090 def @authorization end |
Instance Method Details
#to_headers ⇒ Object
2098 2099 2100 2101 2102 |
# File 'lib/stytch/b2b_organizations.rb', line 2098 def to_headers headers = {} headers.merge!(@authorization.to_headers) if headers end |