Class: StytchB2B::Organizations::Members::DeleteMFAPhoneNumberRequestOptions
- Inherits:
-
Object
- Object
- StytchB2B::Organizations::Members::DeleteMFAPhoneNumberRequestOptions
- Defined in:
- lib/stytch/b2b_organizations.rb
Instance Attribute Summary collapse
-
#authorization ⇒ Object
Optional authorization object.
Instance Method Summary collapse
-
#initialize(authorization: nil) ⇒ DeleteMFAPhoneNumberRequestOptions
constructor
A new instance of DeleteMFAPhoneNumberRequestOptions.
- #to_headers ⇒ Object
Constructor Details
#initialize(authorization: nil) ⇒ DeleteMFAPhoneNumberRequestOptions
Returns a new instance of DeleteMFAPhoneNumberRequestOptions.
841 842 843 844 845 |
# File 'lib/stytch/b2b_organizations.rb', line 841 def initialize( authorization: nil ) @authorization = end |
Instance Attribute Details
#authorization ⇒ Object
Optional authorization object. Pass in an active Stytch Member session token or session JWT and the request will be run using that member’s permissions.
839 840 841 |
# File 'lib/stytch/b2b_organizations.rb', line 839 def @authorization end |
Instance Method Details
#to_headers ⇒ Object
847 848 849 850 851 |
# File 'lib/stytch/b2b_organizations.rb', line 847 def to_headers headers = {} headers.merge!(@authorization.to_headers) if headers end |