Class: StytchB2B::Organizations::Members::DeletePasswordRequestOptions
- Inherits:
-
Object
- Object
- StytchB2B::Organizations::Members::DeletePasswordRequestOptions
- Defined in:
- lib/stytch/b2b_organizations.rb
Instance Attribute Summary collapse
-
#authorization ⇒ Object
Optional authorization object.
Instance Method Summary collapse
-
#initialize(authorization: nil) ⇒ DeletePasswordRequestOptions
constructor
A new instance of DeletePasswordRequestOptions.
- #to_headers ⇒ Object
Constructor Details
#initialize(authorization: nil) ⇒ DeletePasswordRequestOptions
Returns a new instance of DeletePasswordRequestOptions.
898 899 900 901 902 |
# File 'lib/stytch/b2b_organizations.rb', line 898 def initialize( authorization: nil ) @authorization = end |
Instance Attribute Details
#authorization ⇒ Object
Optional authorization object. Pass in an active Stytch Member session token or session JWT and the request will be run using that member’s permissions.
896 897 898 |
# File 'lib/stytch/b2b_organizations.rb', line 896 def @authorization end |
Instance Method Details
#to_headers ⇒ Object
904 905 906 907 908 |
# File 'lib/stytch/b2b_organizations.rb', line 904 def to_headers headers = {} headers.merge!(@authorization.to_headers) if headers end |